@@ -1,7 +1,7 @@
 #
 #  This file is part of WebDyne.
 #
-#  This software is copyright (c) 2026 by Andrew Speer <andrew.speer@isolutions.com.au>.
+#  This software is copyright (c) 2025 by Andrew Speer <andrew.speer@isolutions.com.au>.
 #
 #  This is free software; you can redistribute it and/or modify it under
 #  the same terms as the Perl 5 programming language system itself.
@@ -39,7 +39,7 @@ use WebDyne::Util;
 
 #  Version information
 #
-$VERSION='2.074_566';
+$VERSION='2.014';
 
 
 #  Debug load
@@ -71,7 +71,7 @@ my %Package;
 #
 BEGIN {
     eval {require Time::HiRes;    Time::HiRes->import('time')};
-    eval {require Devel::Confess; Devel::Confess->import(qw(no_warnings))};
+    eval {require Devel::Confess; Devel::Confess->import()};
     eval {} if $@;
 }
 
@@ -84,36 +84,37 @@ sub new {
     #  example. wdcompile is only used for debugging - we do some q&d stuff here
     #  to make it work
     #
-    my ($class, @opt)=@_;
-    my %opt=(ref($opt[0]) eq 'HASH') ? %{$opt[0]} : @opt;
-    debug("$class, opt: %s", Dumper(\%opt));
-
-
-    #  Init WebDyne module
-    #
-    require WebDyne::Request::Fake;
-    my $r=WebDyne::Request::Fake->new( filename=> ( $opt{'filename'} || $opt{'srce'} ) );
+    my ($class, $opt_hr)=@_;
 
 
     #  Get appropriate cgi_or
     #
-    my $html_tag_or=WebDyne::HTML::Tiny->new(mode => $WEBDYNE_HTML_TINY_MODE, r=>$r ) ||
+    my $html_tag_or=WebDyne::HTML::Tiny->new(mode => 'html') ||
         return err('unable to get new WebDyne::HTML::Tiny object');
 
 
+    #  Init WebDyne module
+    #
+    WebDyne->init_class();
+    require WebDyne::Request::Fake;
+    my $r=WebDyne::Request::Fake->new();
+
+
     #  New self ref
     #
     my %self=(
 
-        _r 	=> $r,
-        _CGI  	=> $html_tag_or,
+        _r => $r,
+
+        #_CGI  => $html_tag_or,
 
     );
 
 
     #  And return blessed ref
     #
-    return bless(\%self, 'WebDyne');
+    return bless \%self, 'WebDyne';
+
 
 }
 
@@ -173,21 +174,14 @@ sub compile {
             last;
         }
     }
-    
-    
-    #  Supply html_tiny object ref to Treebuilder so it can run things like start_html
-    #
-    my $html_tiny_or=$self->html_tiny() ||
-        return err('unable to get html_tiny_or ref');
 
 
     #  Get new TreeBuilder object. Note api_version flows through to HTML::Parser constructor
     #
     my $tree_or=WebDyne::HTML::TreeBuilder->new(
 
-        api_version 	=> 3,
-        html_tiny_or   	=> $html_tiny_or,
-        r		=> $r
+        api_version => 3,
+        webdyne	    => $self
 
     ) || return err('unable to create HTML::TreeBuilder object');
 
@@ -233,6 +227,7 @@ sub compile {
 
     #  Muck around with strictness of P tags
     #
+    #$tree_or->implicit_tags(0);
     $tree_or->p_strict(
         exists($param_hr->{'p_strict'}) 
             ? $param_hr->{'p_strict'} 
@@ -249,7 +244,7 @@ sub compile {
     #  man page.
     #
     $tree_or->parse($parse_cr);
-    
+
 
     #  Close handler if anything goes wrong below
     #
@@ -272,16 +267,7 @@ sub compile {
     #
     $tree_or->eof();
     $html_fh->close();
-    
-    
-    #  Set flag (tagname) if we have seen <api> or <htmx> tags and want to compact
-    #  our tree to remove unneccessary <html><head><body> etc. since these
-    #  tags will never emit a full html page when used for real. Do here as lost
-    #  after elementify
-    #
-    my $compact_tag=$tree_or->{'_webdyne_compact'};
-    debug("compact_tag: $compact_tag");
-    
+
 
     #  Elementify
     #
@@ -300,8 +286,8 @@ sub compile {
         return err($close_cr->());
     };
     debug("meta after parse %s", Dumper(\%meta));
-    
-    
+
+
     #  Now destroy the HTML::Treebuilder object, or else mem leak occurs
     #
     $close_cr->();
@@ -324,12 +310,8 @@ sub compile {
             all_fg  => 1,
 
         }) || return err();
-    debug('meta_ar: %s', Dumper($meta_ar));
     foreach my $tag_ar (@{$meta_ar}) {
         my $attr_hr=$tag_ar->[WEBDYNE_NODE_ATTR_IX] || next;
-        debug('meta attr_hr: %s', Dumper($attr_hr));
-        $attr_hr=$self->subst_attr(undef, $attr_hr);
-        debug('meta attr_hr post subst: %s', Dumper($attr_hr));
         if ($attr_hr->{'name'}=~/^webdyne$/i) {
             my @meta=split(/;/, $attr_hr->{'content'});
             debug('meta %s', Dumper(\@meta));
@@ -341,9 +323,6 @@ sub compile {
                 my $hr=$self->subst_attr(undef, {$name => $value}) ||
                     return err();
                 $meta{$name}=$hr->{$name};
-                if ($name eq 'cache') {
-                    $meta{'static'} ||= 1;
-                }
             }
 
             #  Do not want anymore
@@ -355,56 +334,7 @@ sub compile {
 
                 }) || return err();
         }
-        elsif (ref($attr_hr->{'content'}) eq 'HASH') {
-            while (my($meta_key, $meta_value)=each %{$attr_hr->{'content'}}) {
-                if ($meta_key=~/^webdyne$/i) {
-                    my @meta=split(/;/, $meta_value);
-                    debug('meta %s', Dumper(\@meta));
-                    foreach my $meta (@meta) {
-                        my ($name, $value)=split(/[=:]/, $meta, 2);
-                        defined($value) || ($value=1);
-                        $meta{$name}=$value;
-                        if ($name eq 'cache') {
-                            $meta{'static'} ||= 1;
-                        }
-                    }
-                }
-            }
-        } 
     }
-    
-    
-    #  And look for any static or cache tags found in start_html and noted 
-    #
-    foreach my $attr (qw(static cache handler)) {
-        if (my $value=$html_tiny_or->{"_${attr}"}) {
-            $meta{$attr}=$value;
-        }
-    }
-    debug('final inode meta: %s', Dumper(\%meta));
-    
-    
-    #  If <api> or <htmx) tag used in page compress down to just the <api>/<htmx> nodes and throw
-    #  everything else away.
-    #
-    if ($compact_tag) {
-    
-        #  Find all the api nodes
-        #
-        my $api_ar=$self->find_node({
-            data_ar	=> $data_ar,
-            tag		=> $compact_tag,
-            all_fg	=> 1
-        });
-        
-        
-        #  And make a new data_ar structure to hold it, throwing everything else
-        #  in the bin
-        #
-        $data_ar=[undef, undef, $api_ar];
-
-    }
-    
 
     #  Construct final webdyne container
     #
@@ -608,7 +538,7 @@ sub optimise_one {
 
     #  Get CGI object and disable shortcut tags (e.g. start_html);
     #
-    my $html_tiny_or=$self->{'_html_tiny_or'} || $self->html_tiny() ||
+    my $html_tiny_or=$self->{'_html_tiny_or'} ||= $self->html_tiny() ||
         return err("unable to get CGI object from self ref");
     debug("CGI $html_tiny_or");
     $html_tiny_or->shortcut_disable();
@@ -674,6 +604,11 @@ sub optimise_one {
         debug("tag $html_tag, attr %s", Dumper($attr_hr));
 
 
+        #  Store data block as hint to error handler should something go wrong
+        #
+        $self->{'_data_ar'}=$data_ar;
+
+
         #  Check to see if any of the attributes will require a subst to be carried out
         #
         my @subst_oper;
@@ -767,21 +702,14 @@ sub optimise_one {
                 debug("about to call $html_tag with attr_hr:%s, data_child: %s", Dumper($attr_hr, \@data_child));
                 my $html=eval {
                     $attr_hr=undef unless keys %{$attr_hr};
-                    if ($html_tiny_or->can($html_tag)) {
-                        debug("calling HTML::Tiny->$html_tag directly to render");
-                        $html_tiny_or->$html_tag(grep {$_} $attr_hr, join(undef, @data_child))
-                    }
-                    else {
-                        debug("calling HTML::Tiny->tag($html_tag) to render");
-                        $html_tiny_or->tag($html_tag, grep {$_} $attr_hr, join(undef, @data_child))
-                    }
+                    $html_tiny_or->$html_tag(grep {$_} $attr_hr, join(undef, @data_child))
 
                     #  Older attempts
                     #
                     #$html_tiny_or->$html_tag(grep {$_} $attr_hr || {}, join(undef, @data_child))
                     #$html_tiny_or->$html_tag($attr_hr || {}, join(undef, grep {$_} @data_child))
-                } || 
-                    
+                } ||
+
                     #  Use errsubst as CGI may have DIEd during eval and be caught by WebDyne SIG handler
                     return errsubst(
                     "CGI tag '<$html_tag>': %s",
@@ -800,7 +728,6 @@ sub optimise_one {
 
             }
 
-
         }
         else {
             debug('fell through node render, no webdyne, subst tags etc.');
@@ -814,24 +741,9 @@ sub optimise_one {
     };
 
 
-    #  Push data block onto stack as error hint
-    #
-    push @{$self->{'_data_ar_err'}}, $data_ar;
-    
-    
     #  Run it
     #
     $data_ar=$compile_cr->($compile_cr, $data_ar) || return err();
-    
-    
-    #  No error, pop error hint
-    #
-    pop @{$self->{'_data_ar_err'}};
-    
-    
-    #  Re-enable shortcuts
-    #
-    $html_tiny_or->shortcut_enable();
 
 
     #  If scalar ref returned it is all HTML - return as plain scalar
@@ -863,7 +775,7 @@ sub optimise_two {
 
     #  Get CGI object and turn off shortcuts like start_html
     #
-    my $html_tiny_or=$self->{'_html_tiny_or'} || $self->html_tiny() ||
+    my $html_tiny_or=$self->{'_html_tiny_or'} ||= $self->html_tiny() ||
         return err("unable to get CGI object from self ref");
     $html_tiny_or->shortcut_disable();
 
@@ -924,6 +836,11 @@ sub optimise_two {
         debug("tag $html_tag");
 
 
+        #  Store data block as hint to error handler should something go wrong
+        #
+        $self->{'_data_ar'}=$data_ar;
+
+
         #  Check if this tag attributes will need substitution (eg ${foo});
         #
         my $subst_fg=$data_ar->[WEBDYNE_NODE_SBST_IX] || delete $attr_hr->{'subst'} ||
@@ -996,11 +913,9 @@ sub optimise_two {
 
                 #  Splice start and end tags for this HTML into appropriate place
                 #
-                splice @{$data_uppr_ar->[WEBDYNE_NODE_CHLD_IX]}, $data_chld_ix, 1, grep {$_}
+                splice @{$data_uppr_ar->[WEBDYNE_NODE_CHLD_IX]}, $data_chld_ix, 1,
                     $html_start,
-                    (WEBDYNE_HTML_NEWLINE && "\n"),
                     @{$data_ar->[WEBDYNE_NODE_CHLD_IX]},
-                    (WEBDYNE_HTML_NEWLINE && "\n"),
                     $html_end;
 
                 #  Done, no need to iterate any more
@@ -1069,9 +984,10 @@ sub optimise_two {
             #  Now render to make HTML and modify the data arrat above us with the rendered code
             #
             debug("compile_cr: if 2");
-            my $html_sr=$self->render_data_ar(
-                data => [$data_ar],
-            ) || return err();
+            my $html_sr=$self->render(
+                {
+                    data => [$data_ar],
+                }) || return err();
             my @data_child_ar=$data_uppr_ar->[WEBDYNE_NODE_CHLD_IX]
                 ?
                 @{$data_uppr_ar->[WEBDYNE_NODE_CHLD_IX]}
@@ -1085,9 +1001,9 @@ sub optimise_two {
 
 
         }
-        elsif (!$data_uppr_ar && $html_tag) {
-        
-        
+        elsif (!$data_uppr_ar) {
+
+
             #  Must be at top node, as nothing above us,
             #  get start and end tag methods
             #
@@ -1117,11 +1033,9 @@ sub optimise_two {
 
             #  Place start and end tags for this HTML into appropriate place
             #
-            my @data=( grep {$_}
+            my @data=(
                 $html_start,
-                (WEBDYNE_HTML_NEWLINE && "\n"),
                 @data_child_ar,
-                (WEBDYNE_HTML_NEWLINE && "\n"),
                 $html_end
             );
 
@@ -1147,27 +1061,14 @@ sub optimise_two {
 
 
         }
-        elsif (!$data_uppr_ar && !$html_tag) {
-        
-        
-            #  Special case generated by page with <api> tags, means we're not going to wrap in <html>
-            #
-            $data_uppr_ar=$data_ar->[WEBDYNE_NODE_CHLD_IX];
-            
-        }
-        
-        
+
+
         #  Return current node
         #
         return $data_uppr_ar;
 
 
     };
-    
-    
-    #  Push data block onto error hint stack in case of compile error
-    #
-    push @{$self->{'_data_ar_err'}}, $data_ar;
 
 
     #  Run it, return whatever it does, allowing for the special case that first stage
@@ -1175,29 +1076,13 @@ sub optimise_two {
     #  single HTML string. In which case return as array ref to allow for correct storage
     #  and rendering.
     #
-    my $ret;
     if (ref($data_ar)) {
-        $ret=$compile_cr->($compile_cr, $data_ar, undef) ||
+        return $compile_cr->($compile_cr, $data_ar, undef) ||
             err()
     }
     else {
-        $ret=[$data_ar];
+        return [$data_ar];
     }
-    
-    
-    #  No errors, pop error hint stack
-    #
-    pop @{$self->{'_data_ar_err'}};
-    
-
-    #  Re-enable shortcuts
-    #
-    $html_tiny_or->shortcut_enable();
-    
-
-    #  And return
-    #
-    return $ret;
 
 }
 
@@ -1324,3 +1209,11 @@ sub parse {
 }
 
 
+sub html_tiny {
+
+    my $self=shift();
+    debug("$self html_tiny instantiate, mode:$WEBDYNE_HTML_TINY_MODE, existing: %s", $self->{'_html_tiny_or'});
+    return (shift()->{'_html_tiny_or'} ||= WebDyne::HTML::Tiny->new(mode => $WEBDYNE_HTML_TINY_MODE)) ||
+        err('unable to instantiate new WebDybe::HTML::Tiny object');
+
+}
