@@ -1,7 +1,7 @@
 #
 #  This file is part of WebDyne.
 #
-#  This software is copyright (c) 2026 by Andrew Speer <andrew.speer@isolutions.com.au>.
+#  This software is copyright (c) 2025 by Andrew Speer <andrew.speer@isolutions.com.au>.
 #
 #  This is free software; you can redistribute it and/or modify it under
 #  the same terms as the Perl 5 programming language system itself.
@@ -30,7 +30,7 @@ use WebDyne::Util;
 
 #  External modules
 #
-use HTTP::Status qw(:constants is_error);
+use HTTP::Status qw(is_success is_error RC_INTERNAL_SERVER_ERROR);
 use File::Spec;
 use Data::Dumper;
 $Data::Dumper::Indent=1;
@@ -38,7 +38,7 @@ $Data::Dumper::Indent=1;
 
 #  Version information
 #
-$VERSION='2.074_566';
+$VERSION='2.014';
 
 
 #  Debug
@@ -129,11 +129,9 @@ sub err_html {
     $r->log_error($errstr);
 
 
-    #  Status must be internal error if not set to something else already
+    #  Status must be internal error
     #
-    unless ($r->status() && (is_error($r->status()))) {
-        $r->status(HTTP_INTERNAL_SERVER_ERROR);
-    }
+    $r->status(RC_INTERNAL_SERVER_ERROR);
 
 
     #  Do not run any more handlers
@@ -141,9 +139,8 @@ sub err_html {
     $r->set_handlers(PerlHandler => undef);
 
 
-    #  Optionally kill this Apache process afterwards to make sure it does
-    #  not behave badly after this error, if that is what the user has
-    #  configured
+    #  Optionally kill this Apache process afterwards to make sure it does not behave
+    #  badly after this error, if that is what the user has configured
     #
     if ($WEBDYNE_ERROR_EXIT) {
         my $cr=sub {CORE::exit()};
@@ -162,9 +159,8 @@ sub err_html {
             "using text error (%s:%s:%s:%s) - update $r content_type",
             $WEBDYNE_ERROR_TEXT, $WEBDYNE_EVAL_SAFE, $self->{'_error_handler_run'}, $cgi_or
         );
-        #$r->content_type('text/plain');
-        $r->content_type($WEBDYNE_CONTENT_TYPE_TEXT);
-        
+        $r->content_type('text/plain');
+
 
         #  Push error
         #
@@ -172,7 +168,6 @@ sub err_html {
             {
 
                 'URI'  => $r->uri(),
-                #'Line' => scalar $self->data_ar_html_line_no(pop @{$self->{'_data_ar_err'}}),
                 'Line' => scalar $self->data_ar_html_line_no(),
 
             });
@@ -204,7 +199,7 @@ sub err_html {
             errstack_ar      => \@errstack,
             err_eval_perl_sr => $self->{'_err_eval_perl_sr'},
             err_eval_line    => $self->{'_err_eval_line'},
-            data_ar_err      => $self->{'_data_ar_err'},
+            data_ar          => $self->{'_data_ar'},
 
         );
 
@@ -243,24 +238,17 @@ sub err_html {
             #  to use internal
             #
             my $data_ar=$container_ar->[$WEBDYNE_CONTAINER_DATA_IX];
-            debug("err_html data_ar: %s", Dumper($param{'data_ar'}));
 
 
             #  Reset render state and render error page
             #
             $self->render_reset($data_ar);
-            #my $html_sr=$self->render({
-##
-#                    data  => $data_ar,
-#                    param => \%param
-#
-#            }) || return $self->err_html('fatal problem in error handler during render: %s !', errstr() || 'undefined error');
-            my $html_sr=$self->render_data_ar(
+            my $html_sr=$self->render({
 
                     data  => $data_ar,
                     param => \%param
 
-            ) || return $self->err_html('fatal problem in error handler during render: %s !', errstr() || 'undefined error');
+                }) || return $self->err_html('fatal problem in error handler during render: %s !', errstr() || 'undefined error');
 
 
             #  Set custom handler
@@ -272,7 +260,7 @@ sub err_html {
 
             #  Clear error stack again, make sure all is clean before we return.
             #
-            errclr(); eval {} if $@;
+            errclr(); eval {undef} if $@;
 
         };
 
@@ -293,7 +281,6 @@ sub err_html {
 
         #  Return result
         #
-        debug("return status: $status");
         return $status
 
     }
