@@ -1,7 +1,7 @@
 #
 #  This file is part of WebDyne.
 #
-#  This software is copyright (c) 2026 by Andrew Speer <andrew.speer@isolutions.com.au>.
+#  This software is copyright (c) 2025 by Andrew Speer <andrew.speer@isolutions.com.au>.
 #
 #  This is free software; you can redistribute it and/or modify it under
 #  the same terms as the Perl 5 programming language system itself.
@@ -16,14 +16,11 @@ package WebDyne::Err::Constant;
 #  Pragma
 #
 use strict qw(vars);
+#use vars   qw($VERSION @ISA %EXPORT_TAGS @EXPORT_OK @EXPORT %Constant);
 use vars   qw($VERSION @ISA %Constant);
 use warnings;
-
-
-#  Does the heavy liftying of importing into caller namespace
-#
-require WebDyne::Constant;
-@ISA=qw(WebDyne::Constant);
+no warnings qw(uninitialized);
+local $^W=0;
 
 
 #  Need the File::Spec module
@@ -33,7 +30,7 @@ use File::Spec;
 
 #  Version information
 #
-$VERSION='2.074_566';
+$VERSION='2.014';
 
 
 #  Hash of constants
@@ -66,7 +63,7 @@ sub class_dn {
 
     #  Get package file name so we can look up in inc
     #
-    (my $class_fn="${class}.pm")=~s{::}{/}g;
+    (my $class_fn="${class}.pm")=~s/::/\//g;
     $class_fn=$INC{$class_fn} ||
         die("unable to find location for $class in \%INC");
 
@@ -78,6 +75,22 @@ sub class_dn {
 }
 
 
-#  Done
+sub import {
+    
+    goto &WebDyne::Constant::import;
+    
+}
+
+
+#  Export constants to namespace, place in export tags
 #
-1;
+#require Exporter;
+require WebDyne::Constant;
+#@ISA=qw(Exporter WebDyne::Constant);
+@ISA=qw(WebDyne::Constant);
+#+__PACKAGE__->local_constant_load(\%Constant);
+#foreach (keys %Constant) {${$_}=$Constant{$_}}
+#@EXPORT=map {'$' . $_} keys %Constant;
+#@EXPORT_OK=@EXPORT;
+#%EXPORT_TAGS=(all => [@EXPORT_OK]);
+#$_=\%Constant;
