@@ -1,7 +1,7 @@
 #
 #  This file is part of WebDyne.
 #
-#  This software is copyright (c) 2026 by Andrew Speer <andrew.speer@isolutions.com.au>.
+#  This software is copyright (c) 2025 by Andrew Speer <andrew.speer@isolutions.com.au>.
 #
 #  This is free software; you can redistribute it and/or modify it under
 #  the same terms as the Perl 5 programming language system itself.
@@ -29,16 +29,14 @@ our @ISA=qw(HTML::Tiny);
 #  External Modules
 #
 use HTML::Tiny;
-#use CGI::Simple;
+use CGI::Simple;
 use Data::Dumper;
-use HTML::Element;
 
 
 #  WebDyne Modules
 #
 use WebDyne::Constant;
 use WebDyne::Util;
-use WebDyne::CGI;
 
 
 #  Constants
@@ -58,7 +56,7 @@ my %Package;
 
 #  Version information
 #
-$VERSION='2.074_566';
+$VERSION='2.014';
 
 
 #  Debug load
@@ -69,7 +67,6 @@ debug("Loading %s version $VERSION", __PACKAGE__);
 #  Trick to allow use of illegal subroutine name to suppport treebuilder comment format
 #
 *{'WebDyne::HTML::Tiny::~comment'}=\&_comment;
-*{'WebDyne::HTML::Tiny::entity_encode'}=sub { return $_[1] };
 
 
 #  All done. Positive return
@@ -96,6 +93,12 @@ sub new {
     debug("$class new, %s", Dumper(\%param));
     
     
+    #  Were we supplied with a CGI::Simple and/or webdyne object ?
+    #
+    my $cgi_or=delete $param{'CGI'};
+    my $webdyne_or=delete $param{'webdyne'};
+    
+
     #  Shortcuts (start_html, start_form etc.) enabled by default.
     #
     &shortcut_enable() unless
@@ -104,14 +107,15 @@ sub new {
         
     #  Get HTML::Tiny ref
     #
-    my $self=$class->SUPER::new( mode=>(delete($param{'mode'}) || $WEBDYNE_HTML_TINY_MODE));
+    my $self=$class->SUPER::new(%param);
     
     
-    #  Save away other supplied params into self ref
+    #  Save away CGI object and return
     #
-    $self->{'_r'}=$param{'r'};
+    ($self->{'_CGI'} ||= $cgi_or) if $cgi_or;
+    ($self->{'_webdyne'} ||= $webdyne_or) if $webdyne_or;
+    
     
-
     #  Done
     #
     return $self;
@@ -137,7 +141,7 @@ sub CGI {
     #
     my $self=shift();
     debug("$self CGI");
-    return ($self->{'_CGI'} ||= WebDyne::CGI->new($self->{'_r'}));
+    return ($self->{'_CGI'} ||= CGI::Simple->new());
     
 }
 
@@ -182,29 +186,21 @@ sub _init {
             if (defined($attr_hr)) {
                 #  Copy attr so don't pollute ref
                 my %attr=%{$attr_hr};
-                my $label=delete $attr{'label'};
-                #my $param_hr=$self->Vars();
-                my $param_hr=$self->CGI->Vars();
+                my $param_hr=$self->Vars();
                 if ($persist{$tag}) {
                     if ($attr{'name'} && (my $value=$param_hr->{$attr{'name'}}) && !$attr{'force'}) {
                         $attr{'value'}=$value;
                     }
                 }
-                
-                #  Wrap in label if needed
-                #
-                if ($label) {
-                    return $self->label(join('', grep {$_} @param, $label) . $self->input({type => $type{tag}, %attr}));
-                }
-                else {
-                    return $self->input({type => $type{$tag} || $tag, %attr}, @param);
-                }
+                return $self->input({type => $type{$tag} || $tag, %attr}, @param);
             }
             else {
                 return $self->input({type => $type{$tag} || $tag}, @param)
             }
 
-        } unless UNIVERSAL::can(__PACKAGE__, $tag);
+            }
+            unless UNIVERSAL::can(__PACKAGE__, $tag);
+
     }
 
 
@@ -304,10 +300,9 @@ sub _start_html {
 
     #  Attributes we are going to use
     #
-    debug('WEBDYNE_START_HTML_PARAM: %s', Dumper($WEBDYNE_START_HTML_PARAM));
+    debug('WEBDYNE_HTML_PARAM: %s', Dumper($WEBDYNE_HTML_PARAM));
     my %attr=(
         %{$WEBDYNE_HTML_PARAM},
-        %{$WEBDYNE_START_HTML_PARAM},
         %{$attr_hr}
     );
     debug('attr: %s', Dumper(\%attr));
@@ -320,7 +315,8 @@ sub _start_html {
 
     #  Pull out meta attributes leaving rest presumably native html tag attribs
     #
-    my %attr_page=map {$_ => delete $attr{$_}}  grep { exists($attr{$_}) } (qw(
+    #my %attr_page=map {$_=>delete $attr_hr->{$_}} qw(
+    my %attr_page=map {$_ => delete $attr{$_}} qw(
         title
         meta
         style
@@ -329,19 +325,7 @@ sub _start_html {
         author
         script
         include
-        include_script
-        include_style
-        static
-        cache
-        handler
-        h1
-        h2
-        h3
-        h4
-        h5
-        h6
-        hr
-    ), keys %{$WEBDYNE_START_HTML_SHORTCUT_HR});
+    );
     debug('start_html %s', Dumper(\%attr_page));
 
 
@@ -350,54 +334,17 @@ sub _start_html {
     my @html=$WEBDYNE_DTD;
 
 
-    #  Static, cache ? If so mark as such in HTML::Tiny object to be 
-    #  reviewed at end of parse by Treebuilder. Not ideal, good enough
-    #
-    foreach my $attr (qw(static cache handler)) {
-        if (my $value=$attr_page{$attr}) {
-            debug("found attr: $attr, setting to value: $value");
-            $self->{"_${attr}"}=$value;
-            $self->{'_static'} ||=1 if ($attr eq 'cache');
-        }
-    }
-    
-    
-    #  Shortcuts ? Add to relevant attributes
-    #
-    foreach my $shortcut (grep {$attr_page{$_}} keys %{$WEBDYNE_START_HTML_SHORTCUT_HR}) {
-        my $shortcut_hr=$WEBDYNE_START_HTML_SHORTCUT_HR->{$shortcut};
-        debug("found shortcut tag: $shortcut, content: %s", Dumper($shortcut_hr));
-        while (my($type, $href_ar)=each %{$shortcut_hr}) {
-            unless (ref($href_ar) eq 'ARRAY') { $href_ar=[$href_ar] }
-            debug("processing type: $type, href: %s", Dumper($href_ar));
-            if (my $type_attr_value_ar=$attr_page{$type}) {
-                 unless (ref($type_attr_value_ar) eq 'ARRAY') { $type_attr_value_ar=[$type_attr_value_ar] }
-                 debug("found existing start_html attr type: $type, content: %s", Dumper($type_attr_value_ar));
-                 push @{$type_attr_value_ar}, @{$href_ar};
-                 $attr_page{$type}=$type_attr_value_ar;
-                 debug("updated start_html attr type: $type to: %s", Dumper($type_attr_value_ar));
-            }
-            else {
-                debug("no start_hrml attr type: $type found, creating with content: %s", Dumper($href_ar));
-                $attr_page{$type}=$href_ar
-            }
-        }
-    }
-
-
     #  Add meta section
     #
     my @meta;
     if (my $hr=$attr_page{'meta'}) {
         debug('have meta hr: %s', Dumper($hr));
-        @meta=$self->meta({content => $attr_page{'meta'}});
-        debug('processed to: %s', Dumper(\@meta));
+        @meta=$self->meta({content => $attr_page{'meta'}})
     }
     else {
         debug('no meta run');
     }
-    
-    
+
     #  Logic error below, replaced by above
     #
     #my @meta=$self->meta({ content=>$attr_page{'meta'} })
@@ -415,92 +362,39 @@ sub _start_html {
     ##push @meta, $self->meta({ content => $WEBDYNE_META }) unless 
 
 
-    #  Base and/or target
-    #
-    my @base;
-    if ($attr_page{'base'} || $attr_page{'target'}) {
-        my %attr_base;
-        $attr_base{'href'} = $attr_page{'base'} if $attr_page{'base'};
-        $attr_base{'target'} = $attr_page{'target'} if $attr_page{'target'};
-        push @base, $self->base(\%attr_base);
-    }
-    
-
     #  Add any stylesheets
     #
     my @link;
-    if (my $style=$attr_page{'style'}) {
-    
-        #  Generate HTML for link tag stylheet
-        #
-        push @link, $self->_start_html_tag('link', 'href', $style, 
-            { rel=>'stylesheet'});
-
+    if ($attr_page{'style'}) {
+        push @link, $self->link({rel => 'stylesheet', href => $attr_page{'style'}})
     }
-    if (my $include_style=$attr_page{'include_style'}) {
-
-        #  Generate HTML to make an include section for any styles user wants, wrap in <style> tag
-        #
-        push @link, $self->_start_html_tag('include', 'file', $include_style, 
-            { wrap =>'style'});
-            
-            
-        #  Used to do this way but only could do single file
-        #
-        #my $html_or=HTML::Element->new('include', wrap=>'style', file => $include_style);
-        #push @link, $html_or->as_HTML();
-    }
-
     if (my $author=$attr_page{'author'}) {
         $author=$self->url_encode($author);
-        my $html_or=HTML::Element->new('link', rel=> 'author', href => sprintf('mailto:%s', $author));
-        push @link, $html_or->as_HTML();
+        push @link, $self->link({rel => 'author', href => sprintf('mailto:%s', $author)});
     }
     
 
-    #  Scripts
+    #  Script
     #
     my @script;
-    if (my $script=$attr_page{'script'}) {
-    
-        #  Script same as style above
-        #
-        push @script, $self->_start_html_tag('script', 'src', $script);
-    }
-    if (my $include_script=$attr_page{'include_script'}) {
-    
-        #  Include script same as style above
-        #
-        push @script, $self->_start_html_tag('include', 'file', $include_script, 
-            { wrap =>'script'});
-
+    if ($attr_page{'script'}) {
+        push @script, $self->script({ src => $attr_page{'script'} });
     }
     
     
-    #  Include any other files
+    #  Include. Not working - commented out at moment
     #
-    my @include;
-    if (my $fn=$attr_page{'include'}) {
-    
-        
-        #  Same as other tags above, generate <include> HTML
-        #
-        push @include, $self->_start_html_tag('include', 'file', $fn);
-        
-        
-        #  Used to do this way
-        #
-        #my $html_or=HTML::Element->new('include', file => $fn);
-        #push @include, $html_or->as_HTML();
+    my $include;
+    if ((my $fn=$attr_page{'include'}) && (my $webdyne_or=$self->{'_webdyne'})) {
         
 
-        #  Older way was experimental
+        #  Experimental
         #
-        #$include=${
-        #    $webdyne_or->include({ file=>$fn, head=>1 }) ||
-        #        return err();
-        #};
-        #debug("include: $include");
+        $include=${
+            $webdyne_or->include({ file=>$fn, head=>1 }) ||
+                return err();
+        };
+        debug("include: $include");
 
     }
     else {
@@ -516,39 +410,11 @@ sub _start_html {
     
     #  Build title
     #
-    my ($title, $title_html);
-    unless (@include && (grep {/<title>.*?<\/title>/i} @include)) {
-        if (defined($attr_page{'title'})) {
-            #  Title is defined (presumably some string)
-            #
-            debug('title attr defined, using: %s', $attr_page{'title'});
-            $title_html=$self->title($title=$attr_page{'title'});
-        }
-        elsif (exists($attr_page{'title'})) {
-            #  Exists but undefined, leave title undef also
-            #
-            debug('title attr exists but undefined, leaving undefined');
-            $title=undef;
-        }
-        else {
-            #  No title attr at all, use default
-            #
-            debug('title attr not present, using default title');
-            $title_html=$self->title($title=$WEBDYNE_HTML_DEFAULT_TITLE);
-        }
+    my $title;
+    unless ($include && $include=~/<title>.*?<\/title>/i) {
+        $title=$attr_page{'title'} || $WEBDYNE_HTML_DEFAULT_TITLE;
     }
     debug('title: %s', $title || '*undef*');
-    
-    
-    #  Add title as introductory heading if wanted
-    #
-    my $heading_html='';
-    if (my ($heading_tag)=grep {$attr_page{$_}} qw(h1 h2 h3 h4 h5 h6)) {
-        $heading_html=$self->$heading_tag($title) if $title;
-        if ($attr_page{'hr'}) {
-            $heading_html.=$self->hr();
-        }
-    }
         
 
     #  Build head, adding a title section, empty if none specified
@@ -556,47 +422,28 @@ sub _start_html {
     my $head=$self->SUPER::head(
         join(
             $/,
-            grep {$_} (
-                $title_html,
-                @meta,
-                @base,
-                @link,
-                @script,
-                @include
-            )
+            grep {$_}
+                #$self->title($attr_page{'title'} ? $attr_page{'title'} : $WEBDYNE_HTML_DEFAULT_TITLE),
+                $title && $self->title($title),
+            #$title,
+            @meta,
+            @link,
+            @script,
+            $include
         ));
 
 
     #  Put all together and return
     #
     #push @html, $self->open('html', $attr_hr), $head . $self->open('body');
-    push @html, $self->open('html', \%attr), $head . $self->open('body') . $heading_html;
+    push @html, $self->open('html', \%attr), $head . $self->open('body');
     debug('html: %s', Dumper(\@html));
     return join($/, @html);
 
 }
 
 
-sub _start_html_tag {
-
-    my ($self, $tag, $attr, $param_ar, $attr_hr)=@_;
-    my @html;
-    unless (ref($param_ar) eq 'ARRAY') {
-        $param_ar=[$param_ar];
-    }
-    if ($WEBDYNE_START_HTML_PARAM_STATIC) {
-        $attr_hr->{'static'}=1;
-    }
-    foreach my $param (@{$param_ar}) {
-        my $html_or=HTML::Element->new($tag, $attr=>$param, %{$attr_hr} );
-        push @html, $html_or->as_HTML();
-    }
-    return join('', @html);
-    
-}
-        
-
-sub _end_html0 { # No longer needed
+sub _end_html {
 
     #  Stub for WebDyne UNIVERSAL::can to find
     #
@@ -656,8 +503,7 @@ sub _start_form {
     debug("$self _start_form, attr_hr:%s param:%s", Dumper($attr_hr, \@param));
     my %default=(
         method  => 'post',
-        # Redundant
-        # enctype => +URL_ENCODED
+        enctype => +URL_ENCODED
     );
     map {$attr_hr->{$_} ||= $default{$_}}
         keys %default;
@@ -674,7 +520,7 @@ sub _start_multipart_form {
 }
 
 
-sub end_multipart_form {
+sub _end_multipart_form {
     debug("$_[0] _end_multipart_form");
     return shift()->end_form(@_);
 }
@@ -686,12 +532,7 @@ sub _comment {
 
     my ($self, $attr_hr)=@_;
     debug("$self comment, attr:%s", Dumper($attr_hr));
-    #return sprintf("\n<!-- %s -->\n", $attr_hr->{'text'});
-    my $html=sprintf('<!-- %s -->', $attr_hr->{'text'});
-    if (WEBDYNE_HTML_NEWLINE) {
-        $html="\n${html}\n";
-    }
-    return $html;
+    return sprintf('<!-- %s -->', $attr_hr->{'text'});
 
 }
 
@@ -774,54 +615,15 @@ sub script {
 
     my ($self, $attr_hr, @param)=@_;
     debug("$self script, attr %s", Dumper($attr_hr));
-    
-    
-    #  Take copy of attribute hash ref so we don't alter original
-    #
     my @html;
-    my %attr=%{$attr_hr};
-    if ($attr{'src'}) {
-    
-    
-	    #  Convert to array
-	    #
-        my $script_ar;
-        unless (ref($script_ar=$attr{'src'}) eq 'ARRAY') {
-            $script_ar=[$script_ar]
-        }
-        debug('attr_hr: %s, script_ar: %s', Dumper($attr_hr, $script_ar));
-        
-        #  Iterate over each one
-        #
-        foreach my $src (@{$script_ar}) {
-            debug("src: $src");
-            my %src_attr=%attr;
-            
-            #  Split off any fragments and use them as attributes, e.g. #defer becomes defer, ?foo=bar becomes foo=bar in attr
-            my @src=split(/#/, $src);
-            $src=$src[0];
-            debug("src post split: $src");
-            if ($src[1]) {
-                debug('split src: %s', Dumper(\@src));
-                foreach my $kv (split /&/, $src[1]) {
-                    next unless length($kv);
-                    if ( $kv =~ /^([^=]+)=(.*)$/ ) {
-                        $src_attr{$1}=$2;
-                    }
-                    else {
-                        # no “=” means flag parameter
-                        $src_attr{$kv} = [];
-                    }
-                }
-                debug("fragment attr: $src[1] decoded as %s from query_param: %s", Dumper(\%attr, \@src));
-            }
-            push @html, $self->SUPER::script({%src_attr, src => $src}, @param)
-        }
+    if (ref($attr_hr->{'src'}) eq 'ARRAY') {
+        my %attr=%{$attr_hr};
+        my $src_ar=delete $attr{'src'};
+        map {push @html, $self->SUPER::script({%attr, src => $_}, @param)} @{$src_ar}
     }
     else {
         push @html, $self->SUPER::script($attr_hr, @param)
     }
-    debug('html: %s', Dumper(\@html));
     return join($/, @html);
 
 }
@@ -861,12 +663,6 @@ sub _radio_checkbox_group {
     #
     my $param_hr=($self->{'_Vars'} ||= $self->Vars()) ||
         return err('unable able to CGI::Simple Vars');
-        
-        
-    #  And CGI object
-    #
-    my $cgi_or=$self->CGI() ||
-        return err('unable to get CGI object');
 
 
     #  Hold generated HTML in array until end
@@ -881,7 +677,6 @@ sub _radio_checkbox_group {
         map {$attr_group{$attr}{$_}=1} @{(ref($attr{$attr}) eq 'ARRAY') ? $attr{$attr} : [$attr{$attr}]}
             if $attr{$attr};
     }
-    debug('attr_group: %s', Dumper(\%attr_group));
 
 
     #  If values is a hash not an array then convert to array and use hash as values
@@ -899,18 +694,12 @@ sub _radio_checkbox_group {
 
     #  Make sure checked values persist by default unless "force" attribute used to override
     #
-    #if ($attr_hr->{'name'} && (my $checked=$param_hr->{$attr_hr->{'name'}}) && !$attr_hr->{'force'}) {
-    if ($attr_hr->{'name'} && (my @checked=$cgi_or->param($attr_hr->{'name'})) && !$attr_hr->{'force'}) {
+    if ($attr_hr->{'name'} && (my $checked=$param_hr->{$attr_hr->{'name'}}) && !$attr_hr->{'force'}) {
 
         #  The tag has a name, and has some selected (checked) values from a form submision. Map the submitted values 
         #  into the checked attribute, splitting on \0 as per spec
         #
-        #  UPDATE: changed to accommodate use of Hash::Multivalue params now
-        #
-        my @checked=$cgi_or->param($attr_hr->{'name'});
-        debug('checked: %s', Dumper(\@checked));
-        #$attr_group{'checked'} = { map { $_=>1 } (split(/\0/, $checked)) }
-        $attr_group{'checked'} = { map { $_=>1 } @checked }
+        $attr_group{'checked'} = { map { $_=>1 } (split(/\0/, $checked)) }
 
     }
     else {
@@ -990,17 +779,6 @@ sub checkbox {
     #
     my $param_hr=($self->{'_Vars'} ||= $self->Vars()) ||
         return err('unable able to CGI::Simple Vars');
-        
-
-    #  And CGI object
-    #
-    my $cgi_or=$self->CGI() ||
-        return err('unable to get CGI object');
-    
-
-    #  Var to hold hidden tag
-    #
-    my $hidden='';
 
     
     #  Massage to set default value of "1" for checkboxes if no value
@@ -1012,8 +790,7 @@ sub checkbox {
             #  Add hidden field with same name but 0 value
             #
             debug("using hidden field for checkbox: $name, setting checked value to 1 if selected");
-            #push @html, $self->hidden({ name=>$name, value=>0, force=>1 });
-            $hidden=$self->hidden({ name=>$name, value=>0, force=>1 });
+            push @html, $self->hidden({ name=>$name, value=>0, force=>1 });
             
             
             #  Set value of this checkbox (if checked) to 1
@@ -1023,14 +800,9 @@ sub checkbox {
             
             #  Add up all values for this checkbox now.
             #
-            #  UPDATE: Changed to accommodate use of Hash::Multivalue params now.            
-            #
             my $checked;
-            #if (my $value=$param_hr->{$name}) {
-            #    map { $checked+=int($_) } split(/\0/, $value);
-            #}
-            if (my @value=$cgi_or->param($name)) {
-                map { $checked+=int($_) } @value;
+            if (my $value=$param_hr->{$name}) {
+                map { $checked+=int($_) } split(/\0/, $value);
             }
             
             
@@ -1074,7 +846,7 @@ sub checkbox {
     #return shift()->_radio_checkbox('checkbox', @_)
     #return $self->_radio_checkbox('checkbox', grep {$_} $attr_hr, @_) . join(undef, grep {$_} @html);
     debug('calling radio_checkbox');
-    return $hidden.$self->_radio_checkbox('checkbox', \%attr, join('', @html))
+    return $self->_radio_checkbox('checkbox', \%attr, join('', @html))
 }
 
 
@@ -1096,20 +868,9 @@ sub popup_menu {
         return err('unable able to CGI::Simple Vars');
 
 
-    #  And CGI object
-    #
-    my $cgi_or=$self->CGI() ||
-        return err('unable to get CGI object');
-
-
     #  Hold generated HTML in array until end
     #
     my @html;
-    
-    
-    #  Pull off any label
-    #
-    my $label=delete $attr_select{'label'};    
 
 
     #  If values is a hash not an array then convert to array and use hash as values
@@ -1175,16 +936,12 @@ sub popup_menu {
     
     #  Make sure selected values persist by default unless "force" attribute used to override
     #
-    #if ($attr_hr->{'name'} && (my $selected=$param_hr->{$attr_hr->{'name'}}) && !$attr_hr->{'force'}) {
-    if ($attr_hr->{'name'} && (my @selected=$cgi_or->param($attr_hr->{'name'})) && !$attr_hr->{'force'}) {
+    if ($attr_hr->{'name'} && (my $selected=$param_hr->{$attr_hr->{'name'}}) && !$attr_hr->{'force'}) {
 
         #  The tag has a name, and has some selected (checked) values from a form submision. Map the submitted values 
         #  into the selected field, splitting on \0 as per spec
         #
-        #  UPDATE: changed to accommodate use of Hash::Multivalue params now
-        #
-        #$attr_option{'selected'} = { map { $_=>1 } (split(/\0/, $selected)) }
-        $attr_option{'selected'} = { map { $_=>1 } @selected }
+        $attr_option{'selected'} = { map { $_=>1 } (split(/\0/, $selected)) }
 
     }
     else {
@@ -1221,6 +978,7 @@ sub popup_menu {
     #  Fix multiple tag if true
     #
     $attr_select{'multiple'}=[] if $attr_select{'multiple'};
+
     #map { delete $attr_select{$_} } (qw(default selected disabled));
     debug('in popup_menu attr_select: %s', Dumper(\%attr_select));
 
@@ -1239,7 +997,6 @@ sub popup_menu {
         $attr_tag{'selected'}=[] if $attr_option{'selected'}{$value};
         $attr_tag{'disabled'}=[] if $attr_option{'disabled'}{$value};
         my $label=$attr_option{'labels'}{$value} ? $attr_option{'labels'}{$value} : $value;
-        #debug("attr_option label: %s, value: $value, label: $label", Dumper($attr_option{'labels'}));
 
         #if ($label) {
         #    push @html, $self->label($self->option(\%attr_tag) . $label);
@@ -1250,22 +1007,12 @@ sub popup_menu {
 
         #}
     }
-    
-    
-    #  Now wrap in label if needed
-    #
-    debug('creating select group with attr: %s, options:%s, label: %s', Dumper(\%attr_select, \@html), $label);
-    if ($label) {
-        return $self->label($label . $self->select(\%attr_select, join($/, @html)));
-    }
-    else {
-        return $self->select(\%attr_select, join($/, @html));
-    }
-    
+
 
     #  Return
     #
-    #return $self->select(\%attr_select, join($/, @html));
+    debug('creating select group with attr: %s, options:%s', Dumper(\%attr_select, \@html));
+    return $self->select(\%attr_select, join($/, @html));
 
 }
 
@@ -1301,11 +1048,6 @@ sub textarea {
     #  Copy attr_hr so don't mangle original
     #
     my %attr=%{$attr_hr};
-    
-    
-    #  Label ?
-    #
-    my $label=delete $attr{'label'};
         
 
     #  Make sure entered text persists unless force in effect
@@ -1320,24 +1062,15 @@ sub textarea {
     }
     
     
-    #  Wrap in label if needed
+    #  Have enough to build now
     #
-    if ($label) {
-        return $self->label( $label . $self->SUPER::textarea(grep {$_} \%attr, $content));
-    }
-    else {
-        #  Have enough to build now
-        #
-        return $self->SUPER::textarea(grep {$_} \%attr, $content);
-    }
+    return $self->SUPER::textarea(grep {$_} \%attr, $content);
     
 }
 
 
 sub AUTOLOAD {
-    debug("AUTOLOAD: $AUTOLOAD");
     if (my ($action, $tag)=($AUTOLOAD=~/\:\:(start|end|open|close)_([^:]+)$/)) {
-        debug("action: $action, tag: $tag");
         *{$AUTOLOAD}=sub {shift()->$action($tag, @_)};
         return &{$AUTOLOAD}(@_);
     }
