@@ -1,7 +1,7 @@
 #
 #  This file is part of WebDyne.
 #
-#  This software is copyright (c) 2026 by Andrew Speer <andrew.speer@isolutions.com.au>.
+#  This software is copyright (c) 2025 by Andrew Speer <andrew.speer@isolutions.com.au>.
 #
 #  This is free software; you can redistribute it and/or modify it under
 #  the same terms as the Perl 5 programming language system itself.
@@ -46,7 +46,7 @@ use Data::Dumper;
 
 #  Version information
 #
-$VERSION='2.074_566';
+$VERSION='2.014';
 
 
 #  Debug load
@@ -80,6 +80,10 @@ debug("Loading %s version $VERSION", __PACKAGE__);
         reset
         defaults
         image_button
+        start_form
+        end_form
+        start_multipart_form
+        end_multipart_form
         isindex
         dump
         include
@@ -89,7 +93,6 @@ debug("Loading %s version $VERSION", __PACKAGE__);
 
 
 #  Update - get from CGI module, add special dump tag
-#
 #%CGI_TAG_IMPLICIT=map {$_ => 1} (
 #
 #    @{$CGI::EXPORT_TAGS{':form'}},
@@ -110,23 +113,7 @@ debug("Loading %s version $VERSION", __PACKAGE__);
 #  associated with each tag below.
 #
 #map {$CGI_TAG_SPECIAL{$_}++} qw(perl script style start_html end_html include);
-map {$CGI_TAG_SPECIAL{$_}++} qw(
-    perl
-    script
-    style
-    start_html
-    end_html
-    start_form
-    end_form
-    start_multipart_form
-    end_multipart_form
-    include
-    div
-    api
-    json
-    htmx
-    table
-);
+map {$CGI_TAG_SPECIAL{$_}++} qw(perl script style start_html end_html include div);
 
 
 #  Nullify Entities encode & decode
@@ -137,26 +124,22 @@ map {$CGI_TAG_SPECIAL{$_}++} qw(
 
 #  Add to islist items in TreeBuilder
 #
-map {$HTML::Tagset::isList{$_}++} keys %CGI_TAG_WEBDYNE;
+map {$HTML::TreeBuilder::isList{$_}++} keys %CGI_TAG_WEBDYNE;
 
 
-#  Need to tell HTML::TagSet about our special elements. 
-# 
-#  Update - used to do this but now done in table() method below
+#  Need to tell HTML::TagSet about our special elements so
 #
-#map {$HTML::Tagset::isTableElement{$_}++} keys %CGI_TAG_WEBDYNE;
-
-
-#  Add to valid body elements - means Treebuilder will automatically 
-#  create html,head,body sections and include this - for truly lazy
-#  that just create a .psp file with no leading start_html
-#
-map { $HTML::Tagset::isBodyElement{$_}++ } qw(htmx json dump);
+map {$HTML::Tagset::isTableElement{$_}++} keys %CGI_TAG_WEBDYNE;
 
 
 #  And that we also block <p> tag closures
 #
-push @HTML::Tagset::p_closure_barriers, keys %CGI_TAG_WEBDYNE;
+push @HTML::TreeBuilder::p_closure_barriers, keys %CGI_TAG_WEBDYNE;
+
+
+#  Local vars neeeded for cross sub comms
+#
+our ($Line_no, $Line_no_next, $Line_no_start, $HTML_Perl_or);
 
 
 #  All done. Positive return
@@ -169,48 +152,36 @@ push @HTML::Tagset::p_closure_barriers, keys %CGI_TAG_WEBDYNE;
 
 sub new {
 
-
-    #  Instantiate new WebDyne::HTML::TreeBuilder object
-    #
-    my ($class, %param)=@_;
-    debug('in %s new(), class: %s, param: %s', __PACKAGE__, (ref($class) || $class), Dumper(\%param));
-    my $self=$class->SUPER::new(%param) ||
+    my $class=shift();
+    debug('in %s new(), class: %s', __PACKAGE__, ref($class) || $class);
+    my $self=$class->SUPER::new(@_) ||
         return err('unable to initialize from %s, using ISA: %s', ref($class) || $class, Dumper(\@ISA));
-        
-        
-    #  We do need a HTML::Tiny object that has been ideally already been instantiated.
-    #
-    $self->{'_html_tiny_or'}=($param{'html_tiny_or'} ||
-        WebDyne::HTML::Tiny->new(mode => $WEBDYNE_HTML_TINY_MODE, r=>$param{'r'}));
-        
-        
-    #  Done
-    #
+    $self->{'_html_tiny_or'}=
+        WebDyne::HTML::Tiny->new(mode => 'html', @_);
     return $self;
 
 }
 
 
-sub line_no_debug {
-
-    my $self=shift();
-    return sprintf("self $self, line_no: %s, line_no_start: %s, line_no_next: %s", @{$self}{qw(_line_no _line_no_start _line_no_next)});
-    
-}
-
-
 sub parse_fh {
 
 
     #  Get self ref, file handle
     #
-    my ($tree_or, $html_fh)=@_;
+    my ($self, $html_fh)=@_;
     debug("parse $html_fh");
 
 
-    #  Delete any left over wedge segments
+    #  Turn off HTML_Perl object global, in case left over from a __PERL__ segment
+    #  at the bottom of the last file parsed. Should never happen, as we check in
+    #  delete() also
     #
-    delete $tree_or->{'_html_wedge_ar'};
+    $HTML_Perl_or && ($HTML_Perl_or=$HTML_Perl_or->delete());
+    #undef $Text_fg;
+    undef $Line_no;
+    undef $Line_no_start;
+    undef $Line_no_next;
+    delete $self->{'_html_wedge_ar'};
 
 
     #  Read over file handle until we get to the first non-comment line (ignores auto added copyright statements)
@@ -219,8 +190,8 @@ sub parse_fh {
         my $pos=tell($html_fh);
         my $line=<$html_fh>;
         if ($line=~/^#/) {
-            ($tree_or->{'_line_no'} ||= 0)++;
-            $tree_or->{'_line_no_next'}=$tree_or->{'_line_no'}+1;
+            ($Line_no ||= 0)++;
+            $Line_no_next=$Line_no+1;
             next;
         }
         else {
@@ -239,16 +210,13 @@ sub parse_fh {
         #  Read in lines of HTML, allowing for "wedged" bits, e.g. from start_html
         #
         my $line;
-        my $html=@{$tree_or->{'_html_wedge_ar'}} ? shift @{$tree_or->{'_html_wedge_ar'}} : ($line=<$html_fh>);
+        my $html=@{$self->{'_html_wedge_ar'}} ? shift @{$self->{'_html_wedge_ar'}} : ($line=<$html_fh>);
         if ($line) {
             debug("line *$line*");
-            debug($tree_or->line_no_debug());
             my @cr=($line=~/\n/g);
-            $tree_or->{'_line_no'}=($tree_or->{'_line_no_next'} || 1);
-            $tree_or->{'_line_no_next'}=$tree_or->{'_line_no'}+@cr;
-            #  Stop auto vivification via hash slice
-            #debug("Line %s, Line_no_next %s, Line_no_start %s cr %s", @{$tree_or}{qw(_line_no _line_no_next _line_no_start)}, scalar @cr);
-            debug("Line %s, Line_no_next %s, Line_no_start %s cr %s", (map {$tree_or->{$_}} qw(_line_no _line_no_next _line_no_start)), scalar @cr);
+            $Line_no=$Line_no_next || 1;
+            $Line_no_next=$Line_no+@cr;
+            debug("Line $Line_no, Line_no_next $Line_no_next, Line_no_start $Line_no_start cr %s", scalar @cr);
         }
 
 
@@ -258,27 +226,7 @@ sub parse_fh {
             debug("add CR at EOF");
             $html.=$/ unless $html=~/(?:\r?\n|\r)$/;
         }
-        
-        
-        #  Ugly hack to fix @ type attribute names in Alpine and Vue. Need to be done in the Parser properly at
-        #  some stage
-        #
-        if (my $attr_convert=$WEBDYNE_ALPINE_VUE_ATTRIBUTE_HACK_ENABLE) {
-            if ($html =~ s{
-                (<\s*[\w:-]+             # match the start of an HTML tag
-                (?:\s+[^>]*?)?)          # non-greedy match of attributes
-                \s@([\w\.-]+)            # match attribute like @click or @keydown.enter
-                (\s*=\s*["'][^"']*["'])  # match = "value" or = 'value'
-            }{
-                "$1 ${attr_convert}:$2$3"
-            }egx) { #" # Fake quote to re-enable syntax highlighting
-                debug("match on AlpineJS attribute syntax hack, line now: $line");
-            }
-            else {
-                debug('no match on AlpineJS attribute syntax hack')
-            }
-        }
-        
+
 
         #  Done, return HTML
         #
@@ -299,8 +247,17 @@ sub delete {
     debug('delete');
 
 
+    #  Get rid of inline HTML object, if still around
+    #
+    $HTML_Perl_or && ($HTML_Perl_or=$HTML_Perl_or->delete());
+
+
     #  Reset script and line number vars
     #
+    #undef $Text_fg;
+    undef $Line_no;
+    undef $Line_no_next;
+    undef $Line_no_start;
     delete $self->{'_html_wedge_ar'};
 
 
@@ -323,26 +280,11 @@ sub tag_parse {
     #  Get the tag, tag attr
     #
     my ($tag, $attr_hr)=@_;
-    
-    
-    #  Get rid of attribute multi-line value if the start with subst chars
-    #
-    foreach my $attr (keys %{$attr_hr}) {
-        my $attr_value=$attr_hr->{$attr};
-        if ($attr_value=~/([\$@%!+*^])\{(\1?)/) {
-            #  Get rid of cr/lf
-            if ($attr_value=~s/\s*[\r\n]+\s*/ /g) {
-                $attr_hr->{$attr}=$attr_value;
-            }
-        }
-    }
-    #map { $attr_hr->{$_}=($attr_hr->{$_}=~s/\s*[\r\n]+\s*/ /gr) } keys %{$attr_hr};
 
 
-    #  Debug. Amended to stop autovivification
+    #  Debug
     #
-    #debug("tag_parse $method, tag: *%s*, line_no: %s, line_no_start: %s, attr_hr:%s ", $tag, @{$self}{qw(_line_no _line_no_start)}, Dumper($attr_hr));
-    debug("tag_parse $method, tag: *%s*, line_no: %s, line_no_start: %s, attr_hr:%s ", $tag, (map {$self->{$_}} qw(_line_no _line_no_start)), Dumper($attr_hr));
+    debug("tag_parse $method, *$tag*, line $Line_no, attr_hr:%s line_no_start $Line_no_start", Dumper($attr_hr));
 
 
     #  Get the parent tag
@@ -383,8 +325,8 @@ sub tag_parse {
         $html_or=$self->$method(@_);
 
     }
-    
-    
+
+
     #  Special case where <perl/block/etc> wraps <head> or <body> tags. HTML::TreeBuilder assumes
     #  head is always under html - we have to hack.
     #
@@ -434,13 +376,15 @@ sub tag_parse {
         #  Yes, is WebDyne tag
         #
         debug("webdyne tag start|end ($tag) dispatch, method $method");
-        #if ($modifier=~/end_/) {
-        #    debug('end tag so changing method to SUPER::end');
-        #    $method='SUPER::end'
-        #}
+        if ($modifier=~/end_/) {
+            debug('end tag so changing method to SUPER::end');
+            $method='SUPER::end'
+        }
 
+        #if (UNIVERSAL::can('WebDyne::HTML::Tiny', $tag) {
         $html_or=$self->tag_parse($method, $tag_actual, $attr_hr);
 
+
     }
 
 
@@ -491,38 +435,17 @@ sub tag_parse {
 
         #  Pass onto our base class for further processing
         #
-        debug("base class method $method, %s", Dumper(\@_));
+        debug("base class method $method");
         $html_or=$self->$method(@_);
 
 
     }
-    
-    
-    #  Do we have a HTML::Element object ?
+
+
+    #  Insert line number if possible
     #
-    if ((my $ref=ref($html_or)) eq 'HTML::Element') {
-        
-        #  Yes
-        #
-        debug("parse returned $ref object, tag: %s, inserting line no", $html_or->tag());
-        @{$html_or}{'_line_no', '_line_no_tag_end'}=@{$self}{qw(_line_no_start _line_no)};
-        
-        
-    }
-    elsif ($ref && ($ref ne 'WebDyne::HTML::TreeBuilder')) {
-    
-        #  That's weird ..
-        #
-        return err("parse returned $ref object, expected 'WebDyne::HTML::Element'");
-        
-    }
-    else {    
-        
-        #  Text
-        #
-        debug('parse returned text (scalar) object');
-        
-    }
+    debug("insert line_no $Line_no, line_no_start $Line_no_start into object ref $html_or");
+    ref($html_or) && (@{$html_or}{'_line_no', '_line_no_tag_end'}=($Line_no_start, $Line_no));
 
 
     #  Returm object ref
@@ -548,7 +471,6 @@ sub block {
 sub script {
 
     my ($self, $method, $tag, $attr_hr, @param)=@_;
-    no warnings 'qw';
     debug("$self script, attr: %s", Dumper($attr_hr));
     my $script_or=$self->$method($tag, $attr_hr, @param);
     if ($attr_hr->{'type'} eq 'application/perl') {
@@ -561,6 +483,7 @@ sub script {
     else {
 
         push @{$self->{'_script_stack'}}, undef;
+        #$Text_fg ||= 'script';
         $self->_text_block_tag('script') unless $self->_text_block_tag();
     }
 
@@ -570,96 +493,16 @@ sub script {
 }
 
 
-sub json0 {
-
-
-    #  No special handling needed, just log for debugging purposes
-    #
-    my ($self, $method, @param)=@_;
-    $self->_text_block_tag('json') unless $self->_text_block_tag();
-    debug("self $self, tag: json, method: $method text_block_tag %s", $self->_text_block_tag());
-    return $self->$method(@param);
-
-}
-
-
-sub table {
-
-
-    #  Modify HTML::Tagset to allow perl/block/htmx tags within a table tag, then pull them out
-    #  when the table tag closes.
-    #
-    my ($self, $method, @param)=@_;
-    debug("self $self, tag: api, method: $method");
-    if ($method eq 'SUPER::start') {
-        map { $HTML::Tagset::isTableElement{$_}=1 } qw(perl block htmx)
-    }
-    elsif ($method eq 'SUPER::end') {
-        map { delete $HTML::Tagset::isTableElement{$_} } qw(perl block htmx)
-    }
-    return $self->$method(@param);
-    
-}
-
-
-sub htmx {
-
-
-    #  Handle normally but set flag showing we are an <htmx> page, will optimise differently
-    #
-    my ($self, $method, $tag, $attr_hr, @param)=@_;
-    debug("self $self, tag: htmx, method: $method, param: %s", Dumper($attr_hr));
-    $self->{'_webdyne_compact'}=$tag if ($attr_hr->{'compact'} || $attr_hr->{'bare'});
-    if (delete $attr_hr->{'perl'}) {
-        my $html_perl_or=$self->$method($tag, $attr_hr);
-        $self->_html_perl_or($html_perl_or);
-        $self->_text_block_tag($tag) unless $self->_text_block_tag();
-        return $html_perl_or;
-    }
-    else {
-        return $self->$method($tag, $attr_hr, @param);
-    }
-
-}
-
-
-sub api {
-
-
-    #  Handle normally but set flag showing we are an <api> page, will optimise differently
-    #
-    my ($self, $method, $tag, $attr_hr, @param)=@_;
-    debug("self $self, tag: api, method: $method");
-    $self->{'_webdyne_compact'}=$tag;
-    if (delete $attr_hr->{'perl'}) {
-        my $html_perl_or=$self->$method($tag, $attr_hr);
-        $self->_html_perl_or($html_perl_or);
-        $self->_text_block_tag($tag) unless $self->_text_block_tag();
-        return $html_perl_or;
-    }
-    else {
-        return $self->$method($tag, $attr_hr, @param);
-    }
-
-}
-
-
 sub json {
 
 
     #  No special handling needed, just log for debugging purposes
     #
-    my ($self, $method, $tag, $attr_hr, @param)=@_;
-    debug("self $self, tag: api, method: $method");
-    if (delete $attr_hr->{'perl'}) {
-        my $html_perl_or=$self->$method($tag, $attr_hr);
-        $self->_html_perl_or($html_perl_or);
-        $self->_text_block_tag($tag) unless $self->_text_block_tag();
-        return $html_perl_or;
-    }
-    else {
-        return $self->$method($tag, $attr_hr, @param);
-    }
+    my ($self, $method)=(shift, shift);
+    #$Text_fg ||= 'json';
+    $self->_text_block_tag('json') unless $self->_text_block_tag();
+    debug("json self $self, method $method, @_ text_block_tag %s", $self->_text_block_tag());
+    $self->$method(@_);
 
 }
 
@@ -668,8 +511,9 @@ sub style {
 
     my ($self, $method)=(shift, shift);
     debug('style');
+    #$Text_fg ||= 'style';
     $self->_text_block_tag('style') unless $self->_text_block_tag();
-    return $self->$method(@_);
+    $self->$method(@_);
 
 }
 
@@ -680,7 +524,7 @@ sub perl {
     #  Special handling of perl tag
     #
     my ($self, $method, $tag, $attr_hr)=@_;
-    debug("tag: *$tag* method: $method");
+    debug("$tag $method");
 
 
     #  Call SUPER method, check if inline
@@ -690,7 +534,6 @@ sub perl {
     if ($tag eq 'perl') {
         unless (grep {exists $attr_hr->{$_}} qw(package method handler)) {
             $html_perl_or->attr(inline => ++$inline);
-            debug("inline: $inline");
         }
     }
     if ($inline) {
@@ -698,8 +541,9 @@ sub perl {
         #  Inline tag, set global var to this element so any extra text can be
         #  added here
         #
-        $self->_html_perl_or($html_perl_or);
-        $self->_text_block_tag($tag) unless $self->_text_block_tag();
+        $HTML_Perl_or=$html_perl_or;
+        #$Text_fg ||= 'perl';
+        $self->_text_block_tag('perl') unless $self->_text_block_tag();
 
 
         #  And return it
@@ -727,13 +571,10 @@ sub process {
     #
     my ($self, $text)=@_;
     debug("process $text");
-    
-    #  Create perl HTMl::Object
-    #
-    my $html_or=HTML::Element->new('perl', inline => 1, perl => $text);
-    debug("insert line_no: %s into object ref $html_or", $self->{'_line_no'});
-    @{$html_or}{'_line_no', '_line_no_tag_end'}=@{$self}{qw(_line_no _line_no)};
-    return $self->tag_parse('SUPER::text', $html_or)
+    my $or=HTML::Element->new('perl', inline => 1, perl => $text);
+    debug("insert line_no $Line_no into object ref $or");
+    @{$or}{'_line_no', '_line_no_tag_end'}=($Line_no_start, $Line_no);
+    $self->tag_parse('SUPER::text', $or)
 
 }
 
@@ -747,18 +588,17 @@ sub start {
     my ($self, $tag)=(shift, shift);
     my $text=$_[2];
     ref($tag) || ($tag=lc($tag));
-    debug("$self start tag '$tag' line_no: %s, %s", $self->{'_line_no'}, Dumper(\@_));
+    debug("$self start tag '$tag' Line_no $Line_no, @_");
     
     my $html_or;
+    #if ($Text_fg) {
     if ($self->_text_block_tag()) {
         $html_or=$self->text($text)
     }
     else {
         my @cr=($text=~/\n/g);
-        $self->{'_line_no_start'}=$self->{'_line_no'}-@cr;
-        #  Amend to stop autovivification
-        #debug("tag $tag line_no: %s, line_no_start: %s", @{$self}{qw(_line_no _line_no_start)});
-        debug("tag $tag line_no: %s, line_no_start: %s", (map {$self->{$_}} qw(_line_no _line_no_start)));
+        $Line_no_start=$Line_no-@cr;
+        debug("tag $tag line_no $Line_no, line_no_start $Line_no_start");
         $html_or=$self->tag_parse('SUPER::start', $tag, @_);
 
     }
@@ -775,9 +615,9 @@ sub end {
     #
     my ($self, $tag)=(shift, shift);
     ref($tag) || ($tag=lc($tag));
-    debug("$self end tag: %s,%s text_block_tag: %s, line_no: %s", Dumper($tag, \@_), $self->_text_block_tag(), $self->{'_line_no'});
-    debug($self->line_no_debug());
-    #debug('self: %s', Dumper($self));
+    #my $text_block_tag=$self->{'_text_block_tag'};
+    #debug("$self end tag: %s,%s text_fg $Text_fg, line $Line_no", Dumper($tag, \@_));
+    debug("$self end tag: %s,%s text_block_tag: %s, line $Line_no", Dumper($tag, \@_), $self->_text_block_tag());
     
     
     #  Var to hold HTML::Element ref if returned, but most methods don't seem to return a HTML ref, just an integer ?
@@ -809,20 +649,20 @@ sub end {
             #  Set the Text_fg to whatever the webdyne tag was (e.g. perl, etc), that way they will see a match and
             #  turn off text mode. NOTE: Not sure this works ?
             #
+            #$Text_fg &&= $webdyne_tag_or->tag();
             $self->_text_block_tag($webdyne_tag_or->tag()) if $self->_text_block_tag();
             debug("text_block_tag now %s, ending $webdyne_tag", $self->_text_block_tag());
-            $self->pos()->{'_line_no_tag_end'}=$self->{'_line_no'} if (ref($self->pos()) eq 'HTML::Element');
             $self->SUPER::end($webdyne_tag, @_);
 
             #  Now end the original div tag
             #
             debug("ending $tag now");
-            $self->pos()->{'_line_no_tag_end'}=$self->{'_line_no'} if (ref($self->pos()) eq 'HTML::Element');
             $ret=$self->SUPER::end($tag, @_);
 
 
             #  Can now unset text flag. See NOTE above, need to check this
             #
+            #$Text_fg=undef;
             $self->_text_block_tag(undef);
 
 
@@ -859,7 +699,6 @@ sub end {
             #  Vanilla div tag, nothing to do
             #
             debug('undef pop off div stack');
-            $self->pos()->{'_line_no_tag_end'}=$self->{'_line_no'} if (ref($self->pos()) eq 'HTML::Element');
             return $ret=$self->SUPER::end($tag, @_);
         }
     }
@@ -885,6 +724,7 @@ sub end {
             #  End perl tag
             #
             debug("end $perl_tag now");
+            #$Text_fg &&= $perl_tag_or->tag();
             $self->_text_block_tag($perl_tag_or->tag()) if $self->_text_block_tag();
             debug("text_block_tag now %s, ending $perl_tag", $self->_text_block_tag());
             $self->SUPER::end($perl_tag, @_);
@@ -893,8 +733,8 @@ sub end {
             #  End script tag
             #
             debug("end $tag now");
-            $self->pos()->{'_line_no_tag_end'}=$self->{'_line_no'} if (ref($self->pos()) eq 'HTML::Element');
             $self->SUPER::end($tag, @_);
+            #$Text_fg=undef;
             $self->_text_block_tag(undef);
 
 
@@ -911,21 +751,23 @@ sub end {
         elsif (0) {
 
             debug('null script stack pop, ignoring');
+            #$Text_fg=undef;
             $self->_text_block_tag(undef);
             return $ret=$self->SUPER::end($tag, @_);
         }
     }
 
 
+    #if ($Text_fg && ($tag eq $Text_fg)) {
     if ($self->_text_block_tag() && ($tag eq $self->_text_block_tag())) {
         debug("match on tag $tag to text_block_tag %s, clearing text_block_tag", $self->_text_block_tag());
+        #$Text_fg=undef;
         $self->_text_block_tag(undef);
-        $self->pos()->{'_line_no_tag_end'}=$self->{'_line_no'} if (ref($self->pos()) eq 'HTML::Element');
         $ret=$self->SUPER::end($tag, @_)
     }
+    #elsif ($Text_fg) {
     elsif ($self->_text_block_tag()) {
         debug('text segment via text_block_tag %s, passing to text handler', $self->_text_block_tag());
-        $self->pos()->{'_line_no_tag_end'}=$self->{'_line_no'} if (ref($self->pos()) eq 'HTML::Element');
         $ret=$self->text($_[0])
     }
     elsif (!$_[0] && delete($self->{'_end_ignore'})) {
@@ -936,12 +778,11 @@ sub end {
         $ret=undef;
     }
     else {
-        debug("normal tag end: $tag, %s", $self->pos()->tag());
-        $self->pos()->{'_line_no_tag_end'}=$self->{'_line_no'} if (ref($self->pos()) eq 'HTML::Element');
+        debug("normal tag end");
         $ret=$self->SUPER::end($tag, @_)
     }
-    
-    
+
+
     #  Done, return
     #
     debug("end ret $ret");
@@ -960,7 +801,7 @@ sub text {
     #  get self ref, text we will process
     #
     my ($self, $text)=@_;
-    debug('text *%s*, text_block_tag %s, pos: %s', $text, $self->_text_block_tag(), $self->{'_pos'});
+    debug("text *$text*, text_block_tag %s, pos: " . $self->{'_pos'}, $self->_text_block_tag());
     
     
     #  Are we chomping text ?
@@ -986,17 +827,19 @@ sub text {
 
     #  Are we in an inline perl block ?
     #
-    #if ($self->_text_block_tag() eq 'perl') {
-    if (grep { $self->_text_block_tag() eq $_ } qw(perl htmx api json)) {
+    #if ($Text_fg eq 'perl') {
+    if ($self->_text_block_tag() eq 'perl') {
 
 
         #  Yes. We have inline perl code, not text. Just add to perl attribute, which
         #  is treated specially when rendering
         #
-        debug('in <perl> tag, appending text to <perl> block');
-        my $html_perl_or=$self->_html_perl_or();
-        $html_perl_or->{'perl'}.=$text;
-        $html_perl_or->{'_line_no_tag_end'}=$self->{'_line_no'};
+        debug('in __PERL__ tag, appending text to __PERL__ block');
+
+        #  Strip leading CR from Perl code so line numbers in errors make sense
+        #unless ($HTML_Perl_or->{'perl'}) { $text=~s/^\n// }
+        $HTML_Perl_or->{'perl'}.=$text;
+        $HTML_Perl_or->{'_line_no_tag_end'}=$Line_no;
 
 
     }
@@ -1015,18 +858,13 @@ sub text {
         #  bottom of the file.
         #
         debug('found __PERL__ tag');
+        #$Text_fg='perl';
         $self->_text_block_tag('perl');
         $self->implicit(0);
-
-        my $html_perl_or;
-        $self->push_content($self->_html_perl_or($html_perl_or=HTML::Element->new('perl', inline => 1)));
-        # Amended to stop autovivification
-        #
-        #debug('insert line_no: %s into object ref: %s', @{$self}{qw(_line_no _html_perl_or)});
-        debug('insert line_no: %s into object ref: %s', (map {$self->{$_}} qw(_line_no _html_perl_or)));
-        @{$html_perl_or}{qw(_line_no _line_no_tag_end)}=@{$self}{qw(_line_no _line_no)};
-        $html_perl_or->{'_code'}++;
-        
+        $self->push_content($HTML_Perl_or=HTML::Element->new('perl', inline => 1));
+        debug("insert line_no $Line_no into object ref $HTML_Perl_or");
+        @{$HTML_Perl_or}{'_line_no', '_line_no_tag_end'}=($Line_no, $Line_no);
+        $HTML_Perl_or->{'_code'}++;
 
     }
     elsif ($text=~/^\W*__END__/) {
@@ -1046,55 +884,26 @@ sub text {
 
             #  Meeds subst. Get rid of cr's at start and end of text after a <perl> tag, stuffs up formatting in <pre> sections
             #
-            #  Amend to stop autovivification
-            #
-            #debug("found subst tag line_no_start: %s, line_no: %s, text '$text', script_stack: %s, %s", @{$self}{qw(_line_no_start _line_no _script_stack)}, Dumper($self->{'_script_stack'}));
-            debug("found subst tag line_no_start: %s, line_no: %s, text '$text', script_stack: %s, %s", (map {$self->{$_}} qw(_line_no_start _line_no _script_stack)), Dumper($self->{'_script_stack'}));
+            debug("found subst tag line_no_start $Line_no_start, line_no $Line_no, text '$text'");
+            my @cr=($text=~/\n/g);
+            if (my $html_or=$self->{'_pos'}) {
+                debug("parent %s", $html_or->tag());
+                if (($html_or->tag() eq 'perl') && !$html_or->attr('inline')) {
+                    debug('hit !');
 
-            #my @cr=($text=~/\n/g);
-            #if (my $html_or=$self->{'_pos'}) {
-            #    debug("parent %s", $html_or->tag());
-            #    if (($html_or->tag() eq 'perl') && !$html_or->attr('inline')) {
-            #        debug('hit !');
-            #
-            #        #  Why did I comment this out ?
-            #        #
-            #        #$text=~s/^\n//;
-            #        #$text=~s/\n$//;
-            #    }
-            #}
-            
-            #  If in <script> block we probably don't want to be running subst over strings we find because ${varname} is valid Javascript 
-            #  syntax and we shouldn't reallt ever need to subs in a script block (user can pass params to script). Nevertheless we'll give
-            #  them a subst option if they want
-            #
-            my $html_or=$self->{'_pos'};
-            my %attr=$html_or->all_external_attr();
-            
-            
-            #  Gets a bit ugly for <script> tags. If <script> is Javascript *dont* run subst over it unless the user insists.
-            #
-            #  First - are we inside a script tag. Easiest way is to see if in script_stack
-            #
-            if (@{$self->{'_script_stack'}} && (!$attr{'type'} || $WEBDYNE_SCRIPT_TYPE_EXECUTABLE_HR->{$attr{'type'}}) && !$attr{'subst'}) {
-            #if (@{$self->{'_script_stack'}} && !$attr{'subst'}) {
-                debug("script_stack present, bypass susbt: parent %s, attr: %s", $html_or->tag(), Dumper(\%attr));
-                $self->tag_parse('SUPER::text', $text)
-            
-            }
-            elsif ($attr{'nosubst'}) {
-                debug('nosubst attr found in attr: %s', Dumper(\%attr));
-                $self->tag_parse('SUPER::text', $text)
-            }
-            else {
-                my $html_subst_or=HTML::Element->new('subst');
-                #  Amend to stop autovivification
-                #debug("insert line_no: %s, line_no_tag_end: %s into object ref $html_subst_or for text $text", @{$self}{qw(_line_no_start _line_no)});
-                debug("insert line_no: %s, line_no_tag_end: %s into object ref $html_subst_or for text $text", (map {$self->{$_}} qw(_line_no_start _line_no)));
-                @{$html_subst_or}{'_line_no', '_line_no_tag_end'}=@{$self}{qw(_line_no _line_no)};
-                $html_subst_or->push_content($text);
-                $self->tag_parse('SUPER::text', $html_subst_or)
+                    #  Why did I comment this out ?
+                    #
+                    #$text=~s/^\n//;
+                    #$text=~s/\n$//;
+                }
             }
+
+            my $or=HTML::Element->new('subst');
+            my $line_no_start=$Line_no;
+            debug("insert line_no $Line_no_start, line_no_tag_end $Line_no into object ref $or for text $text, cr %s", scalar @cr);
+            @{$or}{'_line_no', '_line_no_tag_end'}=($line_no_start, $Line_no);
+            $or->push_content($text);
+            $self->tag_parse('SUPER::text', $or)
         }
         else {
 
@@ -1117,30 +926,26 @@ sub text {
 
 sub comment {
 
+
     #  Handle comments in HTML. Get HTML::Element ref
     #
-    my $self=shift();
-    my $html_or=$self->SUPER::comment(@_);
-    debug("$self html_or: $html_or comment: %s", Dumper(\@_));
+    my $self=shift()->SUPER::comment(@_);
+    debug("$self comment: %s", Dumper(\@_));
 
 
     #  Change tag to 'comment' from '~comment' so we can call comment render sub in WebDyne::HTML::Tidy (can't call sub starting with ~ in perl)
     #
     #$self->tag('comment'); # No longer needed, make ~comment sub work in WebDyne::HTML::Tiny
-    debug("insert line_no: %s into object ref $self", $self->{'_line_no'});
-    @{$html_or}{qw(_line_no _line_no_tag_end)}=@{$self}{qw(_line_no_start _line_no)};
-    return $html_or
+    debug("insert line_no $Line_no into object ref $self");
+    @{$self}{'_line_no', '_line_no_tag_end'}=($Line_no_start, $Line_no);
+    $self;
 
 }
 
 
 sub start_html {
 
-
-    #  Handle this specially, inject into parser after rendering
-    #
     my ($self, $method, $tag, $attr_hr)=@_;
-    debug("self: $self, method: $method, tag: $tag, attr_hr: %s", Dumper($attr_hr));
     push @{$self->{'_html_wedge_ar'}}, (my $html=$self->{'_html_tiny_or'}->$tag($attr_hr));
     return $self;
 
@@ -1152,26 +957,6 @@ sub end_html {
 }
 
 
-sub start_form {
-    &start_html(@_);
-}
-
-
-sub end_form {
-    &start_html(@_);
-}
-
-
-sub start_multipart_form {
-    &start_html(@_);
-}
-
-
-sub end_multipart_form {
-    &start_html(@_);
-}
-
-
 sub include {
 
 
@@ -1264,12 +1049,11 @@ sub div {
 sub _get_set {
 
     my ($key, $self, $value)=@_;
-    debug("$self, key: $key, value: $value, store: %s", ($self->{$key} || '<none>'));
     return (@_==3) ? $self->{$key}=$value : $self->{$key}
     
 }
 
-map { eval("sub $_ { &_get_set($_, \@_) }") }  qw(_text_block_tag _line_no _line_no_next _line_no_start _html_perl_or);
+map { eval("sub $_ { &_get_set($_, \@_) }") }  qw(_text_block_tag _line_no _line_no_next _line_no_start);
 
 
 #  Done
