@@ -1,7 +1,7 @@
 #
 #  This file is part of WebDyne.
 #
-#  This software is copyright (c) 2026 by Andrew Speer <andrew.speer@isolutions.com.au>.
+#  This software is copyright (c) 2025 by Andrew Speer <andrew.speer@isolutions.com.au>.
 #
 #  This is free software; you can redistribute it and/or modify it under
 #  the same terms as the Perl 5 programming language system itself.
@@ -16,16 +16,14 @@ package WebDyne::Install::Apache::Constant;
 #  Pragma
 #
 use strict qw(vars);
-use vars qw($VERSION @ISA %Constant);
 use warnings;
 no warnings qw(uninitialized);
 
 
-#  Does the heavy liftying of importing into caller namespace
+#  Vars to use
 #
-require WebDyne::Constant;
-@ISA=qw(WebDyne::Constant);
-
+#use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT_OK @EXPORT %Constant);
+use vars qw($VERSION @ISA %Constant);
 
 
 #  External modules
@@ -62,7 +60,7 @@ my $ServerRoot;
 
 #  Version information
 #
-$VERSION='2.074_566';
+$VERSION='2.014';
 
 
 #------------------------------------------------------------------------------
@@ -570,6 +568,25 @@ sub mp2_installed {
 }
 
 
-#  Done
+sub import {
+    
+    goto &WebDyne::Constant::import;
+    
+}
+
+
+#  Finalise and export vars
 #
-1;
+debug('final constants: %s', Dumper(\%Constant));
+#require Exporter;
+require WebDyne::Constant;
+#@ISA=qw(Exporter WebDyne::Constant);
+@ISA=qw(WebDyne::Constant);
+
+#  Local constants override globals
+#+__PACKAGE__->local_constant_load(\%Constant);
+#foreach (keys %Constant) {${$_}=$Constant{$_}}
+#@EXPORT=map {'$' . $_} keys %Constant;
+#@EXPORT_OK=@EXPORT;
+#%EXPORT_TAGS=(all => [@EXPORT_OK]);
+#$_=\%Constant;
