@@ -1,7 +1,7 @@
 #
 #  This file is part of WebDyne.
 #
-#  This software is copyright (c) 2026 by Andrew Speer <andrew.speer@isolutions.com.au>.
+#  This software is copyright (c) 2025 by Andrew Speer <andrew.speer@isolutions.com.au>.
 #
 #  This is free software; you can redistribute it and/or modify it under
 #  the same terms as the Perl 5 programming language system itself.
@@ -12,23 +12,20 @@
 #
 
 
-
-#  Constants file
-#
 package WebDyne::Install::Constant;
 
 
 #  Pragma
 #
 use strict qw(vars);
-use vars qw($VERSION @ISA %Constant);
 use warnings;
+no warnings qw(uninitialized);
 
 
-#  Does the heavy liftying of importing into caller namespace
+#  Vars to use
 #
-require WebDyne::Constant;
-@ISA=qw(WebDyne::Constant);
+#use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT_OK @EXPORT %Constant);
+use vars qw($VERSION @ISA %Constant);
 
 
 #  External Modules
@@ -39,7 +36,7 @@ use File::Spec;
 
 #  Version information
 #
-$VERSION='2.074_566';
+$VERSION='2.014';
 
 
 #------------------------------------------------------------------------------
@@ -79,6 +76,23 @@ else {
 );
 
 
-#  Done
+sub import {
+    
+    goto &WebDyne::Constant::import;
+    
+}
+
+
+#  Finalise and export vars
 #
-1;
\ No newline at end of file
+#require Exporter;
+require WebDyne::Constant;
+@ISA=qw(Exporter WebDyne::Constant);
+
+#  Local constants override globals
+#+__PACKAGE__->local_constant_load(\%Constant);
+#foreach (keys %Constant) {${$_}=$Constant{$_}}
+#@EXPORT=map {'$' . $_} keys %Constant;
+#@EXPORT_OK=@EXPORT;
+#%EXPORT_TAGS=(all => [@EXPORT_OK]);
+#$_=\%Constant;
