@@ -1,7 +1,7 @@
 #
 #  This file is part of WebDyne.
 #
-#  This software is copyright (c) 2026 by Andrew Speer <andrew.speer@isolutions.com.au>.
+#  This software is copyright (c) 2025 by Andrew Speer <andrew.speer@isolutions.com.au>.
 #
 #  This is free software; you can redistribute it and/or modify it under
 #  the same terms as the Perl 5 programming language system itself.
@@ -18,8 +18,6 @@ package WebDyne::Request::PSGI;
 #
 use strict qw(vars);
 use vars   qw($VERSION @ISA);
-use warnings;
-no warnings qw(uninitialized);
 
 
 #  External modules
@@ -28,7 +26,6 @@ use File::Spec::Unix;
 use HTTP::Status qw(status_message RC_OK RC_NOT_FOUND RC_FOUND);
 use URI;
 use Data::Dumper;
-use Plack::Request;
 $Data::Dumper::Indent=1;
 
 
@@ -36,18 +33,18 @@ $Data::Dumper::Indent=1;
 #
 use WebDyne::Request::PSGI::Constant;
 use WebDyne::Util;
-use WebDyne::Constant;
+
 
 
 #  Inheritance
 #
 use WebDyne::Request::Fake;
-@ISA=qw(Plack::Request WebDyne::Request::Fake);
+@ISA=qw(WebDyne::Request::Fake);
 
 
 #  Version information
 #
-$VERSION='2.074_566';
+$VERSION='2.014';
 
 
 #  Debug load
@@ -58,11 +55,7 @@ debug("Loading %s version $VERSION", __PACKAGE__);
 #  Save local copy of environment for ref by Dir_config handler. ENV is reset for each request,
 #  so must use a snapshot for simulating r->dir_config
 #
-my %Dir_config_env=%{$WEBDYNE_PSGI_ENV_SET}, (map { $_=>$ENV{$_} } (
-    qw(DOCUMENT_DEFAULT DOCUMENT_ROOT),
-    @{$WEBDYNE_PSGI_ENV_KEEP},
-    grep {/WebDyne/i} keys %ENV
-));
+my %Dir_config_env=%ENV;
 
 
 #  All done. Positive return
@@ -73,130 +66,11 @@ my %Dir_config_env=%{$WEBDYNE_PSGI_ENV_SET}, (map { $_=>$ENV{$_} } (
 #==================================================================================================
 
 
-sub new {
-
-
-    #  New PSGI request
-    #
-    my ($class, %r)=@_;
-    debug("$class, r: %s, calller:%s", Dumper(\%r, [caller(0)]));
-    
-    
-    #  Try to figure out filename user wants
-    #
-    unless ($r{'filename'}) {
-    
-    
-        #  Not supplied - need to work out
-        #
-        debug('filename not supplied, determining from request');
-
-    
-        #  Iterate through options. If *not* supplied by SCRIPT_FILENAME keep going.
-        #
-        my $fn;
-        unless (($fn=$ENV{'SCRIPT_FILENAME'}) && !$r{'uri'}) {
-        
-        
-            #  Need to calc from document root in PSGI environment
-            #
-            debug('not supplied in SCRIPT_FILENAME or r{uri}. calculating');
-            if (my $dn=($r{'document_root'} || $ENV{'DOCUMENT_ROOT'} || $Dir_config_env{'DOCUMENT_ROOT'} || $DOCUMENT_ROOT)) {
-            
-                #  Get from URI and location
-                #
-                my $uri=$r{'uri'} || $ENV{'PATH_INFO'} || $ENV{'SCRIPT_NAME'};
-                debug("uri: $uri");
-                $fn=File::Spec->catfile($dn, split m{/+}, $uri); #/
-                debug("fn: $fn from dn: $dn, uri: $uri");
-                
-            }
-            
-            
-            #  IIS/FastCGI, not tested recently unsure if works
-            #
-            elsif ($fn=$ENV{'PATH_TRANSLATED'}) {
-
-                #  Feel free to let me know a better way under IIS/FastCGI ..
-                my $script_fn=(File::Spec::Unix->splitpath($ENV{'SCRIPT_NAME'}))[2];
-                $fn=~s/\Q$script_fn\E.*/$script_fn/;
-                debug("fn: $fn derived from PATH_TRANSLATED script_fn: $script_fn");
-            }
-            
-            
-            #  Need to add default psp file ?
-            #
-            #unless ($fn=~/\.psp$/) { # fastest
-            unless ($fn=~WEBDYNE_PSP_EXT_RE) { # fastest
-
-                #  Is it a directory that exists ? Only append default document if that is the case, else let the api code
-                #  handle it
-                #
-                if  ((-d $fn) || !$fn) {
-                    
-            
-                    #  Append default doc to path, which appears at moment to be a directory ?
-                    #
-                    my $document_default=$r{'document_default'} || $Dir_config_env{'DOCUMENT_DEFAULT'} || $DOCUMENT_DEFAULT;
-                    debug("appending document default $document_default to fn:$fn");
-                    
-                    #  If absolute path just use it
-                    #
-                    if (File::Spec->file_name_is_absolute($document_default)) {
-                    
-                        #  Yep - absolute path
-                        #
-                        $fn=$document_default
-                    }
-                    else {
-                    
-                        #  Otherwise append to existing path
-                        #
-                        $fn=File::Spec->catfile($fn, split m{/+}, $document_default); #/
-                    }
-                }
-                else {
-                    
-                    #  Not .psp file, do not want
-                    #
-                    $fn=undef;
-                }
-            }
-        }
-
-
-        #  Final sanity check
-        #
-        debug("final fn: $fn");
-        $r{'filename'}=$fn; 
-        
-    }
-    
-    
-    #  Finished, pass back
-    #
-    return bless \%r, $class;
-
-}
-
-
-sub new_from_filename {
-
-    #  Test method, not used
-    #
-    my ($class, $fn, $select_fh)=@_;
-    my %r=(filename=>$fn, select=>$select_fh, env=>\%ENV);
-    return bless(\%r, $class);
-    
-}
-
-
 sub content_type {
 
     my $r=shift();
     my $hr=$r->headers_out();
-    #@_ ? $r->headers_out()->{'Content-Type'}=shift() : $r->SUPER::content_type();
-    return @_ ? $r->headers_out()->{'Content-Type'}=shift() : ($r->headers_out()->{'Content-Type'} || $ENV{'CONTENT_TYPE'});
+    @_ ? $hr->{'Content-Type'}=shift() : $hr->{'Content-Type'};
 
 }
 
@@ -221,71 +95,91 @@ sub filename {
 
 sub header_only {
 
-    (shift()->method() eq 'HEAD') ? 1 : 0 
+    ($ENV{'REQUEST_METHOD'} eq 'HEAD') ? 1 : 0;
 
 }
 
 
 sub headers_in {
-    my $r=shift();
-    return $r->headers();
+
+    my ($r, $header)=@_;
+    my $hr=$r->{'headers_in'} ||= do {
+        my @http_header=grep {/^HTTP_/} keys %ENV;
+        my %http_header=map  {$_ => $ENV{$_}} @http_header;
+        foreach my $k (keys %http_header) {
+            my $v=delete $http_header{$k};
+            $k=~s/^HTTP_//;
+            $k=~s/_/-/g;
+            $http_header{lc($k)}=$v;
+        }
+        \%http_header;
+    };
+    $header ? $hr->{lc($header)} : $hr;
+
 }
 
 
-sub headers_out {
+sub dir_config {
 
-    my $r=shift();
-    return WebDyne::Request::Fake::headers($r, 'headers_out', @_);
+    my ($r, $key)=@_;
 
-}    
+    my $constant_hr=$WEBDYNE_PSGI_DIR_CONFIG;
+
+    my $constant_server_hr;
+    if (my $server=$Dir_config_env{'WebDyneServer'} || $ENV{'SERVER_NAME'}) {
+        $constant_server_hr=$constant_hr->{$server} if exists($constant_hr->{$server})
+    }
+
+    my $location=$r->location();
+    debug("in dir_config looking for key $key at location $location");
+
+    if (exists $constant_server_hr->{$location}) {
+        return $constant_server_hr->{$location}{$key}
+    }
+    elsif (exists $constant_hr->{$location}) {
+        return $constant_hr->{$location}{$key}
+
+        #|| $constant_hr->{undef()}{$key} || $Dir_config_env{$key}
+    }
+    else {
+        debug("explicit location key $key not found, returning top level");
+        return $constant_hr->{''}{$key} || $Dir_config_env{$key}
+    }
+
+}
 
 
 sub location {
 
-
     #  Equiv to Apache::RequestUtil->location;
     #
-    my $r=shift();
-    debug("r: $r, caller: %s", Dumper([caller(0)]));
     my $location;
-    my $constant_hr=$WEBDYNE_DIR_CONFIG;
+    my $constant_hr=$WEBDYNE_PSGI_DIR_CONFIG;
     my $constant_server_hr;
     if (my $server=$Dir_config_env{'WebDyneServer'} || $ENV{'SERVER_NAME'}) {
         $constant_server_hr=$constant_hr->{$server} if exists($constant_hr->{$server})
     }
     if ($Dir_config_env{'WebDyneLocation'} || $ENV{'APPL_MD_PATH'}) {
 
-        #  APPL_MD_PATH is IIS virtual dir. If that or a fixed location set use it.
+        #  APPL_MD_PATH is IIS virtual dir
         #
         $location=$Dir_config_env{'WebDyneLocation'} || $ENV{'APPL_MD_PATH'};
     }
-    elsif (my $uri_path=join('', grep {$_} @ENV{qw(SCRIPT_NAME PATH_INFO)})) {
-        
-        #  Strip file name
-        #
-        $uri_path=~s{[^/]+\Q@{[WEBDYNE_PSP_EXT]}\E$}{}x; #\
-        debug("uri_path: $uri_path");
-        my @location=('/', grep {$_} File::Spec::Unix->splitdir($uri_path));
-        
-        #  Start iterating through directories
-        #
+    elsif ($ENV{'SCRIPT_NAME'}) {
+        my $path=(File::Spec::Unix->splitpath($ENV{'SCRIPT_NAME'}))[1];
+        my @location=grep {$_}
+            File::Spec::Unix->rootdir(), File::Spec::Unix->splitdir($path);
         while ($location=File::Spec::Unix->catdir(@location)) {
-            debug("location: $location");
+            debug("location $location");
             last if exists($constant_hr->{$location}) || exists($constant_server_hr->{$location});
-            $location.='/' unless ($location eq '/');
+            $location.=File::Spec::Unix->rootdir();
             last if exists($constant_hr->{$location}) || exists($constant_server_hr->{$location});
             pop @location;
         }
     }
     else {
-        
-        #  Actually mod_perl spec says location blank if not positively given - don't default to '/'
-        #
-        #$location=File::Spec::Unix->rootdir();
+        $location=File::Spec::Unix->rootdir();
     }
-    
-    #  
-    #
     return $location;
 
 }
@@ -293,8 +187,7 @@ sub location {
 
 sub log_error {
 
-    my $r=shift();
-    warn(@_) if $WEBDYNE_PSGI_WARN_ON_ERROR;
+    shift(); warn(@_) if $WEBDYNE_PSGI_WARN_ON_ERROR;
 
 }
 
@@ -303,7 +196,7 @@ sub lookup_file {
 
     my ($r, $fn)=@_;
     my $r_child;
-    if ($fn!~WEBDYNE_PSP_EXT_RE) { # fastest
+    if ($fn=~/\.html$/) {
 
 
         #  Static file
@@ -337,12 +230,79 @@ sub lookup_uri {
 }
 
 
+sub new0 {
+    
+    
+    #  Create self ref
+    #
+    my ($class, $param)=@_;
+    debug('initiating %s', Dumper($param));
+    return bless(ref($param)?$param:\$param, $class);
+
+}
+
+sub new {
+
+    my ($class, %r)=@_;
+
+    unless ($r{'filename'}) {
+
+        my $fn;
+        unless (($fn=$ENV{'SCRIPT_FILENAME'}) && !$r{'uri'}) {
+
+            if (my $dn=($r{'document_root'} || $Dir_config_env{'DOCUMENT_ROOT'} || $DOCUMENT_ROOT)) {
+            #if (my $dn=($ENV{'DOCUMENT_ROOT'} || $DOCUMENT_ROOT)) {
+                my $uri=$r{'uri'} || $ENV{'REQUEST_URI'};
+                if (my $location=$class->location()) {
+                    $uri=~s/^\Q$location\E//;
+                }
+                my $uri_or=URI->new($uri);
+                $fn=File::Spec->catfile($dn, $uri_or->path());
+                
+                #  If PSP file spec'd on command line get rid of trailing /
+                debug("fn: $fn derived from uri: $uri, dn: $dn");
+                $fn=~s/\.psp\/$/.psp/;
+            }
+            
+            elsif ($fn=$ENV{'PATH_TRANSLATED'}) {
+
+                #  Feel free to let me know a better way under IIS/FastCGI ..
+                my $script_fn=(File::Spec::Unix->splitpath($ENV{'SCRIPT_NAME'}))[2];
+                $fn=~s/\Q$script_fn\E.*/$script_fn/;
+                debug("fn: $fn derived from script_fn: $script_fn");
+            }
+
+            if ($fn=~/\/$/) {
+            
+                #  Append default doc to path, which appears at moment to be a directory ?
+                #
+                debug("appending document default %s to fn:$fn", $r{'document_default'} || $Dir_config_env{'DOCUMENT_DEFAULT'} || $DOCUMENT_DEFAULT);
+                $fn=File::Spec->catfile(grep {$_} $fn,  $r{'document_default'} || $Dir_config_env{'DOCUMENT_DEFAULT'} || $DOCUMENT_DEFAULT);
+                
+            }
+
+        }
+        debug("final fn: $fn");
+
+        $r{'filename'}=$fn || do {
+            #my $env=join("\n", map {"$_=$ENV{$_}"} keys %ENV);
+            return err("unable to determine filename for request from environment:%s, Dir_config_env: %s", Dumper(\%ENV, \%Dir_config_env))
+        };
+
+    }
+
+    bless \%r, $class;
+
+}
+
+
 sub redirect {
 
     my ($r, $location)=@_;
-    $r->status(HTTP_FOUND);
-    $r->headers_out('Location' => $location);
-    return HTTP_FOUND;
+    CORE::print sprintf("Status: %s\r\n", RC_FOUND);
+    CORE::print "Location: $location\r\n";
+    $r->send_http_header;
+    return RC_FOUND;
 
 }
 
@@ -350,30 +310,39 @@ sub redirect {
 sub run {
 
     my ($r, $self)=@_;
-    debug("self: $self, r:$r");
     if (-f $r->{'filename'}) {
-        debug('file is %s', $r->{'filename'});
         return ref($self)->handler($r);
     }
     else {
         debug("file not found !");
         $r->status(RC_NOT_FOUND);
         $r->send_error_message;
-        return HTTP_NOT_FOUND;
+        RC_NOT_FOUND;
     }
 
 }
 
 
+sub set_handlers {
+
+    #  No-op
+
+}
+
+
 sub send_error_response {
 
     my $r=shift();
     my $status=$r->status();
+    CORE::print "Status: $status\r\n";
+    $r->send_http_header;
     debug("in send error response, status $status");
+    #if (my $message_ar=$r->custom_response($status)) {
     if (my $message=$r->custom_response($status)) {
 
         #  We have a custom response - send it
         #
+        #$r->print(@{$message_ar});
         $r->print($message);
 
     }
@@ -396,7 +365,7 @@ sub err_html {
     #
     my ($r, $status, $message)=@_;
     require WebDyne::HTML::Tiny;
-    my $html_or=WebDyne::HTML::Tiny->new( mode=>$WEBDYNE_HTML_TINY_MODE, r=>$r ) ||
+    my $html_or=WebDyne::HTML::Tiny->new() ||
         return err();
     my $error;
     my @message=(
@@ -409,14 +378,41 @@ sub err_html {
         ),
         $html_or->end_html()
     );
-    return join('', @message);
+    return join(undef, @message);
 
 }
 
 
 sub send_http_header {
 
-    #  Stub
-    
+    my $r=shift();
+    return unless $r->{'header'};
+    while (my ($h, $v)=each %{$r->headers_out()}) {
+        CORE::print "$h: $v\r\n";
+    }
+    CORE::print "\r\n";
+
 }
 
+
+sub uri {
+
+    my $r=shift();
+    @_ ? $r->{'uri'}=shift() : $r->{'uri'} || $ENV{'REQUEST_URI'}
+
+}
+
+
+sub protocol {
+
+    $ENV{'SERVER_PROTOCOL'}
+}
+
+
+sub env {
+
+    return \%Dir_config_env;
+
+}
+
+__END__
