@@ -1,7 +1,7 @@
 #
 #  This file is part of WebDyne.
 #
-#  This software is copyright (c) 2026 by Andrew Speer <andrew.speer@isolutions.com.au>.
+#  This software is copyright (c) 2025 by Andrew Speer <andrew.speer@isolutions.com.au>.
 #
 #  This is free software; you can redistribute it and/or modify it under
 #  the same terms as the Perl 5 programming language system itself.
@@ -20,21 +20,21 @@ package WebDyne::Request::PSGI::Constant;
 #  Pragma
 #
 use strict qw(vars);
+#use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT_OK @EXPORT %Constant);
 use vars qw($VERSION @ISA %Constant);
 use warnings;
 
 
-#  Does the heavy liftying of importing into caller namespace
-#
-require WebDyne::Constant;
-@ISA=qw(WebDyne::Constant);
-
-
 #  Version information
 #
-$VERSION='2.074_566';
+$VERSION='2.014';
 
 
+#  Get module file name and path, derive name of file to store local constants
+#
+use Cwd qw(abs_path);
+my $local_fn=abs_path(__FILE__) . '.local';
+
 
 #  Hash of constants
 #  <<<
@@ -53,11 +53,6 @@ $VERSION='2.074_566';
     DOCUMENT_DEFAULT	=> 'app.psp',
     
     
-    #  File to use for indexing
-    #
-    WEBDYNE_PSGI_INDEX	=> 'index.psp',
-    
-    
     #  Middeware config, static module. Loaded by default for convenience if
     #  started via webdyne.psgi script directly (i.e. not invoked by plakup
     #  or starman). Activate in middleware section below if wanted with plackup
@@ -65,16 +60,16 @@ $VERSION='2.074_566';
     #
     #  Serve any static file except .psp
     #
-    #WEBDYNE_PSGI_MIDDLEWARE_STATIC => qr{^(?!.*\.psp$).*\.\w+$},
+    #WEBDYNE_PLACK_MIDDLEWARE_STATIC => qr{^(?!.*\.psp$).*\.\w+$},
     #
     #  Just common files
     #
-    WEBDYNE_PSGI_MIDDLEWARE_STATIC => qr{\.(?:css|js|jpg|jpeg|png|gif|svg|ico|woff2?|ttf|eot|otf|webp|map|txt|inc|htm|html)$}i,
+    WEBDYNE_PLACK_MIDDLEWARE_STATIC => qr{\.(?:css|js|jpg|jpeg|png|gif|svg|ico|woff2?|ttf|eot|otf|webp|map|txt|inc|htm|html)$}i,
     
     
     #  All other middleware. Uncomment/modify as required
     #
-    WEBDYNE_PSGI_MIDDLEWARE => [
+    WEBDYNE_PLACK_MIDDLEWARE_AR => [
         
         #{ 'Debug' => 
         #    { panels => [ qw(Environment) ] } 
@@ -89,10 +84,9 @@ $VERSION='2.074_566';
     ],
     
     
-    #  Environment variables to keep, needs to be array ref
+    #  Dir Config
     #
-    WEBDYNE_PSGI_ENV_KEEP => [qw(DOCUMENT_ROOT DOCUMENT_DEFAULT)],
-    WEBDYNE_PSGI_ENV_SET  => {},
+    WEBDYNE_PSGI_DIR_CONFIG => undef,
     
     
     #  Warn on error ?
@@ -104,8 +98,20 @@ $VERSION='2.074_566';
 # >>>
 
 
-#  Done
+sub import {
+    
+    goto &WebDyne::Constant::import;
+    
+}
+
+
+#  Export constants to namespace, place in export tags
+#
+require WebDyne::Constant;
+@ISA=qw(WebDyne::Constant);
+
+
+#  All done
 #
 1;
-__END__
-
+#===================================================================================================
