@@ -1,7 +1,7 @@
 #
 #  This file is part of WebDyne.
 #
-#  This software is copyright (c) 2026 by Andrew Speer <andrew.speer@isolutions.com.au>.
+#  This software is copyright (c) 2025 by Andrew Speer <andrew.speer@isolutions.com.au>.
 #
 #  This is free software; you can redistribute it and/or modify it under
 #  the same terms as the Perl 5 programming language system itself.
@@ -24,7 +24,6 @@ use vars   qw($VERSION $AUTOLOAD @ISA);
 use HTTP::Status (qw(RC_INTERNAL_SERVER_ERROR RC_NOT_FOUND));
 use IO::File;
 use WebDyne::Util;
-use WebDyne::Constant;
 
 
 #  Inheritance
@@ -35,7 +34,7 @@ use WebDyne::Request::PSGI;
 
 #  Version information
 #
-$VERSION='2.074_566';
+$VERSION='2.014';
 
 
 #  Debug load
@@ -65,8 +64,6 @@ sub run {
         my $hr=$r->headers_out();
         my $size=(stat($fn))[7];
         $hr->{'Content-Length'}=$size;
-        my $ext=($fn=~/\.(\w+)$/) && $1;
-        $hr->{'Content-Type'}=$WEBDYNE_MIME_TYPE_HR->{$ext} || $WEBDYNE_CONTENT_TYPE_TEXT;
         $r->send_http_header();
         while (<$fh>) {$r->print($_)}
         $fh->close();
