@@ -1,7 +1,7 @@
 #
 #  This file is part of WebDyne.
 #
-#  This software is copyright (c) 2026 by Andrew Speer <andrew.speer@isolutions.com.au>.
+#  This software is copyright (c) 2025 by Andrew Speer <andrew.speer@isolutions.com.au>.
 #
 #  This is free software; you can redistribute it and/or modify it under
 #  the same terms as the Perl 5 programming language system itself.
@@ -12,27 +12,19 @@
 #
 
 
-#  Constants file  
+#  Constants
 #
 package WebDyne::Session::Constant;
-
-
-#  Pragma
-#
 use strict qw(vars);
+#use vars   qw($VERSION @ISA %EXPORT_TAGS @EXPORT_OK @EXPORT %Constant);
 use vars   qw($VERSION @ISA %Constant);
-use warnings;
-
-
-#  Does the heavy liftying of importing into caller namespace
-#
-require WebDyne::Constant;
-@ISA=qw(WebDyne::Constant);
+no warnings qw(uninitialized);
+local $^W=0;
 
 
 #  Version information. Must be all on one line
 #
-$VERSION='2.074_566';
+$VERSION='2.014';
 
 
 #  The guts
@@ -47,6 +39,15 @@ $VERSION='2.074_566';
 );
 
 
-#  Done
+#  Export constants to namespace, place in export tags
 #
-1;
\ No newline at end of file
+#require Exporter;
+require WebDyne::Constant;
+#@ISA=qw(Exporter WebDyne::Constant);
+@ISA=qw(WebDyne::Constant);
+#+__PACKAGE__->local_constant_load(\%Constant);
+#foreach (keys %Constant) {${$_}=$Constant{$_}}
+#@EXPORT=map {'$' . $_} keys %Constant;
+#@EXPORT_OK=@EXPORT;
+#%EXPORT_TAGS=(all => [@EXPORT_OK]);
+#$_=\%Constant;
