@@ -1,7 +1,7 @@
 #
 #  This file is part of WebDyne.
 #
-#  This software is copyright (c) 2026 by Andrew Speer <andrew.speer@isolutions.com.au>.
+#  This software is copyright (c) 2025 by Andrew Speer <andrew.speer@isolutions.com.au>.
 #
 #  This is free software; you can redistribute it and/or modify it under
 #  the same terms as the Perl 5 programming language system itself.
@@ -34,7 +34,7 @@ use File::Spec;
 #  Version information in a formate suitable for CPAN etc. Must be
 #  all on one line
 #
-$VERSION='2.074_566';
+$VERSION='2.014';
 
 
 #  Debug
@@ -149,7 +149,7 @@ sub filter {
 
     #  The real guts. Wedge one HTML page into a wrapper page
     #
-    my ($self, $data_content_ar, $meta_content_hr)=@_;
+    my ($self, $data_main_ar, $meta_main_hr)=@_;
     debug("in $self filter");
 
 
@@ -171,7 +171,7 @@ sub filter {
     #  just show as is
     #
     ($template_cn eq $r->filename()) &&
-        return $data_content_ar;
+        return $data_main_ar;
 
 
     #  Get the template structure data ref
@@ -187,16 +187,16 @@ sub filter {
 
     #  Concatenate meta perl sections
     #
-    #my $perl_content_ar=$meta_content_hr->{'perl'};
+    #my $perl_main_ar=$meta_main_hr->{'perl'};
     my $perl_template_ar=$meta_template_hr->{'perl'};
-    push @{$meta_content_hr->{'perl'}}, @{$perl_template_ar};
+    push @{$meta_main_hr->{'perl'}}, @{$perl_template_ar};
 
 
     #  Below fixes up HEAD section
     #
 
 
-    #  Find head block, ie <head> tag in data ref
+    #  Find body block, ie <head> tag in data ref
     #
     my $data_template_head_ar=(
         $self->find_node({
@@ -244,28 +244,28 @@ sub filter {
         Dumper($data_template_head_block_ar));
 
 
-    #  Get the <head> section from the content HTML page, ie the page to be
+    #  Get the <head> section from the main HTML page, ie the page to be
     #  embedded
     #
-    my $data_content_head_ar=(
+    my $data_main_head_ar=(
         $self->find_node({
 
-                data_ar => $data_content_ar,
+                data_ar => $data_main_ar,
                 tag     => 'head'
 
             })
             || return err())->[0];
     debug(
-        "data_content_head_ar $data_content_head_ar %s",
-        Dumper($data_content_head_ar));
+        "data_main_head_ar $data_main_head_ar %s",
+        Dumper($data_main_head_ar));
 
 
     #  Concatenate titles
     #
-    my $data_content_title_ar=(
+    my $data_main_title_ar=(
         $self->find_node({
 
-                data_ar => $data_content_ar,
+                data_ar => $data_main_ar,
                 tag     => 'title'
 
             })
@@ -278,39 +278,35 @@ sub filter {
 
             })
             || return err())->[0];
-    $data_template_title_ar->[WEBDYNE_NODE_CHLD_IX][0]=join(
+    $data_main_title_ar->[$WEBDYNE_NODE_CHLD_IX][0]=join(
         ' - ',
         grep {$_}
-            $data_template_title_ar->[WEBDYNE_NODE_CHLD_IX][0], $data_content_title_ar->[WEBDYNE_NODE_CHLD_IX][0]);
-    #$data_template_title_ar->[WEBDYNE_NODE_CHLD_IX][0]=$data_content_title_ar->[WEBDYNE_NODE_CHLD_IX][0];
+            $data_template_title_ar->[$WEBDYNE_NODE_CHLD_IX][0], $data_main_title_ar->[$WEBDYNE_NODE_CHLD_IX][0]);
 
-    debug('titles, %s, %s', Dumper($data_content_title_ar, $data_template_title_ar));
-    #die;
+    #debug('titles, %s, %s', Dumper($data_main_title_ar, $data_template_title_ar));
 
 
     #  Replace menu head attr with any head attr from main page
     #
-    #die Dumper($data_template_head_ar);
-    $data_template_head_ar->[WEBDYNE_NODE_ATTR_IX]=
-        $data_content_head_ar->[WEBDYNE_NODE_ATTR_IX];
-    #die Dumper($data_template_head_ar);
+    $data_template_head_ar->[$WEBDYNE_NODE_ATTR_IX]=
+        $data_main_head_ar->[$WEBDYNE_NODE_ATTR_IX];
 
 
     #  Search for head block in head block parent
     #
-    foreach my $data_chld_ix (0..$#{$data_template_head_block_prnt_ar->[WEBDYNE_NODE_CHLD_IX]}) {
+    foreach my $data_chld_ix (0..$#{$data_template_head_block_prnt_ar->[$WEBDYNE_NODE_CHLD_IX]}) {
 
 
         #  Skip if not found
         #
-        my $data_chld_ar=$data_template_head_block_prnt_ar->[WEBDYNE_NODE_CHLD_IX][$data_chld_ix];
+        my $data_chld_ar=$data_template_head_block_prnt_ar->[$WEBDYNE_NODE_CHLD_IX][$data_chld_ix];
         next unless ($data_chld_ar eq $data_template_head_block_ar);
 
 
         #  Must have found node if get to here, splice in head
         #
-        splice @{$data_template_head_block_prnt_ar->[WEBDYNE_NODE_CHLD_IX]}, $data_chld_ix, 1,
-            @{$data_content_head_ar->[WEBDYNE_NODE_CHLD_IX]};
+        splice @{$data_template_head_block_prnt_ar->[$WEBDYNE_NODE_CHLD_IX]}, $data_chld_ix, 1,
+            @{$data_main_head_ar->[$WEBDYNE_NODE_CHLD_IX]};
         last;
 
     }
@@ -371,40 +367,40 @@ sub filter {
     #  Get the <body> section from the main HTML page, ie the page to be
     #  embedded
     #
-    my $data_content_body_ar=(
+    my $data_main_body_ar=(
         $self->find_node({
 
-                data_ar => $data_content_ar,
+                data_ar => $data_main_ar,
                 tag     => 'body'
 
             })
             || return err())->[0];
     debug(
-        "data_content_body_ar $data_content_body_ar %s",
-        Dumper($data_content_body_ar));
+        "data_main_body_ar $data_main_body_ar %s",
+        Dumper($data_main_body_ar));
 
 
     #  Replace menu body attr with any body attr from main page
     #
-    $data_template_body_ar->[WEBDYNE_NODE_ATTR_IX]=
-        $data_content_body_ar->[WEBDYNE_NODE_ATTR_IX];
+    $data_template_body_ar->[$WEBDYNE_NODE_ATTR_IX]=
+        $data_main_body_ar->[$WEBDYNE_NODE_ATTR_IX];
 
 
     #  Search for body block in body block parent
     #
-    foreach my $data_chld_ix (0..$#{$data_template_body_block_prnt_ar->[WEBDYNE_NODE_CHLD_IX]}) {
+    foreach my $data_chld_ix (0..$#{$data_template_body_block_prnt_ar->[$WEBDYNE_NODE_CHLD_IX]}) {
 
 
         #  Skip if not found
         #
-        my $data_chld_ar=$data_template_body_block_prnt_ar->[WEBDYNE_NODE_CHLD_IX][$data_chld_ix];
+        my $data_chld_ar=$data_template_body_block_prnt_ar->[$WEBDYNE_NODE_CHLD_IX][$data_chld_ix];
         next unless ($data_chld_ar eq $data_template_body_block_ar);
 
 
         #  Must have found node if get to here, splice in body
         #
-        splice @{$data_template_body_block_prnt_ar->[WEBDYNE_NODE_CHLD_IX]}, $data_chld_ix, 1,
-            @{$data_content_body_ar->[WEBDYNE_NODE_CHLD_IX]};
+        splice @{$data_template_body_block_prnt_ar->[$WEBDYNE_NODE_CHLD_IX]}, $data_chld_ix, 1,
+            @{$data_main_body_ar->[$WEBDYNE_NODE_CHLD_IX]};
         last;
 
 
@@ -420,10 +416,53 @@ sub filter {
 
 __END__
 
-=begin markdown
+=head1 Name
+
+WebDyne::Template - WebDyne extension module that implements document templating
+
+=head1 Description
+
+WebDyne::Template is a WebDyne extension module that implements document
+templating.  You can set templates for locations or sites, e.g.  menu
+sidebars, header, copyright information etc.  All psp documents within the
+scope of the location will then be embedded into the templates.
+
+Templates are WebDyne documents also - they can dynamically change (e.g.
+cascading menus, breadcrumb tracking etc.) based on any arbitrary criterea
+you determine.
+
+The target documents within the templating location do not have to be
+modified - the WebDyne::Template module will parse out head and body
+sections of requested documents and embed them into the location template as
+appropriate
+
+=head1 Documentation
+
+Information on configuration and usage is availeble from the WebDyne site,
+http://webdyne.org/ - or from a snapshot of current documentation in PDF
+format available in the WebDyne module source /doc directory.
+
+=head1 LICENSE and COPYRIGHT
+
+This file is part of WebDyne.
+
+This software is copyright (c) 2025 by Andrew Speer L<mailto:andrew.speer@isolutions.com.au>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+Full license text is available at:
+
+L<http://dev.perl.org/licenses/>
+
+=head1 Author
+
+Andrew Speer, andrew@webdyne.org
+
+=head1 Bugs
+
+Please report any bugs or feature requests to "bug-webdyne-template at
+rt.cpan.org", or via
+http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WebDyne-Template
 
 
-=end markdown
-
-
-=cut
