@@ -1,7 +1,7 @@
 #
 #  This file is part of WebDyne.
 #
-#  This software is copyright (c) 2026 by Andrew Speer <andrew.speer@isolutions.com.au>.
+#  This software is copyright (c) 2025 by Andrew Speer <andrew.speer@isolutions.com.au>.
 #
 #  This is free software; you can redistribute it and/or modify it under
 #  the same terms as the Perl 5 programming language system itself.
@@ -42,7 +42,7 @@ require Exporter;
 
 #  Version information
 #
-$VERSION='2.074_566';
+$VERSION='2.014';
 
 
 #  Var to hold package wide hash, for data shared across package, and error stack
@@ -50,12 +50,6 @@ $VERSION='2.074_566';
 my (%Package, @Err);
 
 
-#  Bring the WEBDYNE_DEBUG env var into package var so available via Plack handler,
-#  which normally replaces env with its own
-#
-$Package{'WEBDYNE_DEBUG'}=$ENV{'WEBDYNE_DEBUG'};
-
-
 #  All done. Positive return
 #
 1;
@@ -225,49 +219,43 @@ sub debug {
         return undef;
     my $method=(caller(1))[3] || 'main';
     (my $subroutine=$method)=~s/^.*:://;
-    (my $class=$method)=~s/::\Q${subroutine}\E$//;
 
 
     #  Time in human readable format
     #
     my ($sec, $msec)=gettimeofday();
+
+    #my $timestamp=strftime("%Y-%m-%d %H:%M:%S", localtime($sec)) . sprintf(".%04d", $msec);
     my $timestamp=strftime("%H:%M:%S", localtime($sec)) . sprintf('.%06d', $msec);
 
 
     #  Get the debug message
     #
-    #local $SIG{__WARN__}=sub { require Carp; &Carp::confess @_ };  #uncomment if want to trace any missing sprintf params
-    my $debug=$#_ ? sprintf(shift(), @_) : shift();
+    my $debug=$_[1] ? sprintf(shift(), @_) : shift();
 
 
     #  Filtering ?
     #
-    if ($Package{'WEBDYNE_DEBUG'} && ($Package{'WEBDYNE_DEBUG'} ne '1')) {
+    if ($ENV{'WEBDYNE_DEBUG'} && ($ENV{'WEBDYNE_DEBUG'} ne '1')) {
 
 
         #  Yes - check we are getting from caller we are interested in
         #
-        my @debug_target=split(/[,;]/, $Package{'WEBDYNE_DEBUG'});
+        my @debug_target=split(/[,;]/, $ENV{'WEBDYNE_DEBUG'});
         foreach my $debug_target (@debug_target) {
             if (($caller eq $debug_target) || ($method=~/\Q$debug_target\E$/)) {
-            
-                #  Print debug after checking for any regexp wanted
-                #
-                if (my $regexp=$ENV{'WEBDYNE_DEBUG_FILTER'}) {
-                    next unless $debug=~qr/$regexp/m;
-                }
-                CORE::print $debug_fh "[$timestamp $class ($subroutine)] ", $debug, $/;
+
+                #CORE::print $debug_fh "[$timestamp $subroutine] ", $_[1] ? sprintf(shift(), @_) : $_[0], $/;
+                CORE::print $debug_fh "[$timestamp $subroutine] ", $debug, $/;
             }
         }
     }
     else {
 
-        #  No filtering. Open floodgates but still apply any regexp
+        #  No filtering. Open floodgates
         #
-        if (my $regexp=$ENV{'WEBDYNE_DEBUG_FILTER'}) {
-            return unless $debug=~qr/$regexp/;
-        }
-        CORE::print $debug_fh "[$timestamp $class ($subroutine)] ", $debug, $/;
+        #CORE::print $debug_fh "[$timestamp $subroutine] ", $_[1] ? sprintf(shift(), @_) : $_[0], $/;
+        CORE::print $debug_fh "[$timestamp $subroutine] ", $debug, $/;
     }
 
 }
